/* dummy-full-persona.c generated by valac 0.35.3.10-6b27, the Vala compiler
 * generated from dummy-full-persona.vala, do not modify */

/*
 * Copyright (C) 2013 Philip Withnall
 * Copyright (C) 2013 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *       Philip Withnall <philip@tecnocode.co.uk>
 *       Travis Reitter <travis.reitter@collabora.co.uk>
 *       Marco Barisione <marco.barisione@collabora.co.uk>
 *       Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <folks/folks.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <folks-internal.h>


#define FOLKS_DUMMY_TYPE_PERSONA (folks_dummy_persona_get_type ())
#define FOLKS_DUMMY_PERSONA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FOLKS_DUMMY_TYPE_PERSONA, FolksDummyPersona))
#define FOLKS_DUMMY_PERSONA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FOLKS_DUMMY_TYPE_PERSONA, FolksDummyPersonaClass))
#define FOLKS_DUMMY_IS_PERSONA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FOLKS_DUMMY_TYPE_PERSONA))
#define FOLKS_DUMMY_IS_PERSONA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FOLKS_DUMMY_TYPE_PERSONA))
#define FOLKS_DUMMY_PERSONA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FOLKS_DUMMY_TYPE_PERSONA, FolksDummyPersonaClass))

typedef struct _FolksDummyPersona FolksDummyPersona;
typedef struct _FolksDummyPersonaClass FolksDummyPersonaClass;
typedef struct _FolksDummyPersonaPrivate FolksDummyPersonaPrivate;

#define FOLKS_DUMMY_TYPE_FULL_PERSONA (folks_dummy_full_persona_get_type ())
#define FOLKS_DUMMY_FULL_PERSONA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FOLKS_DUMMY_TYPE_FULL_PERSONA, FolksDummyFullPersona))
#define FOLKS_DUMMY_FULL_PERSONA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FOLKS_DUMMY_TYPE_FULL_PERSONA, FolksDummyFullPersonaClass))
#define FOLKS_DUMMY_IS_FULL_PERSONA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FOLKS_DUMMY_TYPE_FULL_PERSONA))
#define FOLKS_DUMMY_IS_FULL_PERSONA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FOLKS_DUMMY_TYPE_FULL_PERSONA))
#define FOLKS_DUMMY_FULL_PERSONA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FOLKS_DUMMY_TYPE_FULL_PERSONA, FolksDummyFullPersonaClass))

typedef struct _FolksDummyFullPersona FolksDummyFullPersona;
typedef struct _FolksDummyFullPersonaClass FolksDummyFullPersonaClass;
typedef struct _FolksDummyFullPersonaPrivate FolksDummyFullPersonaPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

#define FOLKS_DUMMY_TYPE_PERSONA_STORE (folks_dummy_persona_store_get_type ())
#define FOLKS_DUMMY_PERSONA_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FOLKS_DUMMY_TYPE_PERSONA_STORE, FolksDummyPersonaStore))
#define FOLKS_DUMMY_PERSONA_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FOLKS_DUMMY_TYPE_PERSONA_STORE, FolksDummyPersonaStoreClass))
#define FOLKS_DUMMY_IS_PERSONA_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FOLKS_DUMMY_TYPE_PERSONA_STORE))
#define FOLKS_DUMMY_IS_PERSONA_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FOLKS_DUMMY_TYPE_PERSONA_STORE))
#define FOLKS_DUMMY_PERSONA_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FOLKS_DUMMY_TYPE_PERSONA_STORE, FolksDummyPersonaStoreClass))

typedef struct _FolksDummyPersonaStore FolksDummyPersonaStore;
typedef struct _FolksDummyPersonaStoreClass FolksDummyPersonaStoreClass;
typedef struct _Block3Data Block3Data;
typedef struct _FolksDummyFullPersonaChangeWebServiceAddressesData FolksDummyFullPersonaChangeWebServiceAddressesData;
typedef struct _Block4Data Block4Data;
typedef struct _FolksDummyFullPersonaChangeLocalIdsData FolksDummyFullPersonaChangeLocalIdsData;
typedef struct _Block5Data Block5Data;
typedef struct _FolksDummyFullPersonaChangePostalAddressesData FolksDummyFullPersonaChangePostalAddressesData;
typedef struct _Block6Data Block6Data;
typedef struct _FolksDummyFullPersonaChangePhoneNumbersData FolksDummyFullPersonaChangePhoneNumbersData;
typedef struct _Block7Data Block7Data;
typedef struct _FolksDummyFullPersonaChangeEmailAddressesData FolksDummyFullPersonaChangeEmailAddressesData;
typedef struct _Block8Data Block8Data;
typedef struct _FolksDummyFullPersonaChangeNotesData FolksDummyFullPersonaChangeNotesData;
typedef struct _Block9Data Block9Data;
typedef struct _FolksDummyFullPersonaChangeAvatarData FolksDummyFullPersonaChangeAvatarData;
typedef struct _Block10Data Block10Data;
typedef struct _FolksDummyFullPersonaChangeStructuredNameData FolksDummyFullPersonaChangeStructuredNameData;
typedef struct _Block11Data Block11Data;
typedef struct _FolksDummyFullPersonaChangeFullNameData FolksDummyFullPersonaChangeFullNameData;
typedef struct _Block12Data Block12Data;
typedef struct _FolksDummyFullPersonaChangeNicknameData FolksDummyFullPersonaChangeNicknameData;
typedef struct _Block13Data Block13Data;
typedef struct _FolksDummyFullPersonaChangeGenderData FolksDummyFullPersonaChangeGenderData;
typedef struct _Block14Data Block14Data;
typedef struct _FolksDummyFullPersonaChangeUrlsData FolksDummyFullPersonaChangeUrlsData;
typedef struct _Block15Data Block15Data;
typedef struct _FolksDummyFullPersonaChangeImAddressesData FolksDummyFullPersonaChangeImAddressesData;
typedef struct _FolksDummyFullPersonaChangeGroupData FolksDummyFullPersonaChangeGroupData;
typedef struct _Block16Data Block16Data;
typedef struct _FolksDummyFullPersonaChangeGroupsData FolksDummyFullPersonaChangeGroupsData;
typedef struct _Block17Data Block17Data;
typedef struct _FolksDummyFullPersonaChangeCalendarEventIdData FolksDummyFullPersonaChangeCalendarEventIdData;
typedef struct _Block18Data Block18Data;
typedef struct _FolksDummyFullPersonaChangeBirthdayData FolksDummyFullPersonaChangeBirthdayData;
typedef struct _Block19Data Block19Data;
typedef struct _FolksDummyFullPersonaChangeRolesData FolksDummyFullPersonaChangeRolesData;
typedef struct _Block20Data Block20Data;
typedef struct _FolksDummyFullPersonaChangeIsFavouriteData FolksDummyFullPersonaChangeIsFavouriteData;
typedef struct _Block21Data Block21Data;
typedef struct _FolksDummyFullPersonaChangeAntiLinksData FolksDummyFullPersonaChangeAntiLinksData;
#define _t_destroy_func0(var) (((var == NULL) || (t_destroy_func == NULL)) ? NULL : (var = (t_destroy_func (var), NULL)))
#define _s_destroy_func0(var) (((var == NULL) || (s_destroy_func == NULL)) ? NULL : (var = (s_destroy_func (var), NULL)))

struct _FolksDummyPersona {
	FolksPersona parent_instance;
	FolksDummyPersonaPrivate * priv;
};

struct _FolksDummyPersonaClass {
	FolksPersonaClass parent_class;
};

struct _FolksDummyFullPersona {
	FolksDummyPersona parent_instance;
	FolksDummyFullPersonaPrivate * priv;
};

struct _FolksDummyFullPersonaClass {
	FolksDummyPersonaClass parent_class;
};

struct _FolksDummyFullPersonaPrivate {
	GeeHashMultiMap* _web_service_addresses;
	GeeHashSet* _local_ids;
	GeeSet* _local_ids_ro;
	GeeHashSet* _postal_addresses;
	GeeSet* _postal_addresses_ro;
	GeeHashSet* _phone_numbers;
	GeeSet* _phone_numbers_ro;
	GeeHashSet* _email_addresses;
	GeeSet* _email_addresses_ro;
	GeeHashSet* _notes;
	GeeSet* _notes_ro;
	GLoadableIcon* _avatar;
	FolksStructuredName* _structured_name;
	gchar* _full_name;
	gchar* _nickname;
	FolksGender _gender;
	GeeHashSet* _urls;
	GeeSet* _urls_ro;
	GeeHashMultiMap* _im_addresses;
	GeeHashSet* _groups;
	GeeSet* _groups_ro;
	gchar* _calendar_event_id;
	GDateTime* _birthday;
	GeeHashSet* _roles;
	GeeSet* _roles_ro;
	gboolean _is_favourite;
	GeeHashSet* _anti_links;
	GeeSet* _anti_links_ro;
};

struct _Block3Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	GeeMultiMap* web_service_addresses;
	gpointer _async_data_;
};

typedef void (*FolksDummyPersonaChangePropertyCallback) (void* user_data);
struct _FolksDummyFullPersonaChangeWebServiceAddressesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	GeeMultiMap* web_service_addresses;
	Block3Data* _data3_;
	GeeMultiMap* _tmp0_;
};

struct _Block4Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	GeeSet* local_ids;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeLocalIdsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	GeeSet* local_ids;
	Block4Data* _data4_;
	GeeSet* _tmp0_;
};

struct _Block5Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	GeeSet* postal_addresses;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangePostalAddressesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	GeeSet* postal_addresses;
	Block5Data* _data5_;
	GeeSet* _tmp0_;
};

struct _Block6Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	GeeSet* phone_numbers;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangePhoneNumbersData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	GeeSet* phone_numbers;
	Block6Data* _data6_;
	GeeSet* _tmp0_;
};

struct _Block7Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	GeeSet* email_addresses;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeEmailAddressesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	GeeSet* email_addresses;
	Block7Data* _data7_;
	GeeSet* _tmp0_;
};

struct _Block8Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	GeeSet* notes;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeNotesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	GeeSet* notes;
	Block8Data* _data8_;
	GeeSet* _tmp0_;
};

struct _Block9Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	GLoadableIcon* avatar;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeAvatarData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	GLoadableIcon* avatar;
	Block9Data* _data9_;
	GLoadableIcon* _tmp0_;
};

struct _Block10Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	FolksStructuredName* structured_name;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeStructuredNameData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	FolksStructuredName* structured_name;
	Block10Data* _data10_;
	FolksStructuredName* _tmp0_;
};

struct _Block11Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	gchar* full_name;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeFullNameData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	gchar* full_name;
	Block11Data* _data11_;
	const gchar* _tmp0_;
};

struct _Block12Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	gchar* nickname;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeNicknameData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	gchar* nickname;
	Block12Data* _data12_;
	const gchar* _tmp0_;
};

struct _Block13Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	FolksGender gender;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeGenderData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	FolksGender gender;
	Block13Data* _data13_;
	FolksGender _tmp0_;
};

struct _Block14Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	GeeSet* urls;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeUrlsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	GeeSet* urls;
	Block14Data* _data14_;
	GeeSet* _tmp0_;
};

struct _Block15Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	GeeMultiMap* im_addresses;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeImAddressesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	GeeMultiMap* im_addresses;
	Block15Data* _data15_;
	GeeMultiMap* _tmp0_;
};

struct _FolksDummyFullPersonaChangeGroupData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	gchar* group;
	gboolean is_member;
	gboolean _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	GeeHashSet* _tmp3_;
	const gchar* _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
	gboolean _tmp7_;
	GeeHashSet* _tmp8_;
	const gchar* _tmp9_;
	gboolean _tmp10_;
	GeeHashSet* new_groups;
	GeeHashSet* _tmp11_;
	GeeIterator* _category_name_it;
	GeeHashSet* _tmp12_;
	GeeIterator* _tmp13_;
	GeeIterator* _tmp14_;
	gboolean _tmp15_;
	gchar* category_name;
	GeeIterator* _tmp16_;
	gpointer _tmp17_;
	GeeHashSet* _tmp18_;
	const gchar* _tmp19_;
	gboolean _tmp20_;
	GeeHashSet* _tmp21_;
	const gchar* _tmp22_;
	GeeHashSet* _tmp23_;
	const gchar* _tmp24_;
	GeeHashSet* _tmp25_;
	GError * _inner_error_;
};

struct _Block16Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	GeeSet* groups;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeGroupsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	GeeSet* groups;
	Block16Data* _data16_;
	GeeSet* _tmp0_;
};

struct _Block17Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	gchar* calendar_event_id;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeCalendarEventIdData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	gchar* calendar_event_id;
	Block17Data* _data17_;
	const gchar* _tmp0_;
};

struct _Block18Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	GDateTime* bday;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeBirthdayData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	GDateTime* bday;
	Block18Data* _data18_;
	GDateTime* _tmp0_;
};

struct _Block19Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	GeeSet* roles;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeRolesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	GeeSet* roles;
	Block19Data* _data19_;
	GeeSet* _tmp0_;
};

struct _Block20Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	gboolean is_favourite;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeIsFavouriteData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	gboolean is_favourite;
	Block20Data* _data20_;
	gboolean _tmp0_;
};

struct _Block21Data {
	int _ref_count_;
	FolksDummyFullPersona* self;
	GeeSet* anti_links;
	gpointer _async_data_;
};

struct _FolksDummyFullPersonaChangeAntiLinksData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyFullPersona* self;
	GeeSet* anti_links;
	Block21Data* _data21_;
	GeeSet* _tmp0_;
};


static gpointer folks_dummy_full_persona_parent_class = NULL;
static FolksAntiLinkableIface * folks_dummy_full_persona_folks_anti_linkable_parent_iface = NULL;
static FolksAvatarDetailsIface * folks_dummy_full_persona_folks_avatar_details_parent_iface = NULL;
static FolksBirthdayDetailsIface * folks_dummy_full_persona_folks_birthday_details_parent_iface = NULL;
static FolksEmailDetailsIface * folks_dummy_full_persona_folks_email_details_parent_iface = NULL;
static FolksFavouriteDetailsIface * folks_dummy_full_persona_folks_favourite_details_parent_iface = NULL;
static FolksGenderDetailsIface * folks_dummy_full_persona_folks_gender_details_parent_iface = NULL;
static FolksGroupDetailsIface * folks_dummy_full_persona_folks_group_details_parent_iface = NULL;
static FolksImDetailsIface * folks_dummy_full_persona_folks_im_details_parent_iface = NULL;
static FolksLocalIdDetailsIface * folks_dummy_full_persona_folks_local_id_details_parent_iface = NULL;
static FolksNameDetailsIface * folks_dummy_full_persona_folks_name_details_parent_iface = NULL;
static FolksNoteDetailsIface * folks_dummy_full_persona_folks_note_details_parent_iface = NULL;
static FolksPhoneDetailsIface * folks_dummy_full_persona_folks_phone_details_parent_iface = NULL;
static FolksRoleDetailsIface * folks_dummy_full_persona_folks_role_details_parent_iface = NULL;
static FolksUrlDetailsIface * folks_dummy_full_persona_folks_url_details_parent_iface = NULL;
static FolksPostalAddressDetailsIface * folks_dummy_full_persona_folks_postal_address_details_parent_iface = NULL;
static FolksWebServiceDetailsIface * folks_dummy_full_persona_folks_web_service_details_parent_iface = NULL;

GType folks_dummy_persona_get_type (void) G_GNUC_CONST;
GType folks_dummy_full_persona_get_type (void) G_GNUC_CONST;
#define FOLKS_DUMMY_FULL_PERSONA_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), FOLKS_DUMMY_TYPE_FULL_PERSONA, FolksDummyFullPersonaPrivate))
enum  {
	FOLKS_DUMMY_FULL_PERSONA_DUMMY_PROPERTY,
	FOLKS_DUMMY_FULL_PERSONA_WEB_SERVICE_ADDRESSES,
	FOLKS_DUMMY_FULL_PERSONA_LOCAL_IDS,
	FOLKS_DUMMY_FULL_PERSONA_POSTAL_ADDRESSES,
	FOLKS_DUMMY_FULL_PERSONA_PHONE_NUMBERS,
	FOLKS_DUMMY_FULL_PERSONA_EMAIL_ADDRESSES,
	FOLKS_DUMMY_FULL_PERSONA_NOTES,
	FOLKS_DUMMY_FULL_PERSONA_AVATAR,
	FOLKS_DUMMY_FULL_PERSONA_STRUCTURED_NAME,
	FOLKS_DUMMY_FULL_PERSONA_FULL_NAME,
	FOLKS_DUMMY_FULL_PERSONA_NICKNAME,
	FOLKS_DUMMY_FULL_PERSONA_GENDER,
	FOLKS_DUMMY_FULL_PERSONA_URLS,
	FOLKS_DUMMY_FULL_PERSONA_IM_ADDRESSES,
	FOLKS_DUMMY_FULL_PERSONA_GROUPS,
	FOLKS_DUMMY_FULL_PERSONA_CALENDAR_EVENT_ID,
	FOLKS_DUMMY_FULL_PERSONA_BIRTHDAY,
	FOLKS_DUMMY_FULL_PERSONA_ROLES,
	FOLKS_DUMMY_FULL_PERSONA_IS_FAVOURITE,
	FOLKS_DUMMY_FULL_PERSONA_ANTI_LINKS
};
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
GType folks_dummy_persona_store_get_type (void) G_GNUC_CONST;
FolksDummyFullPersona* folks_dummy_full_persona_new (FolksDummyPersonaStore* store, const gchar* contact_id, gboolean is_user, gchar** linkable_properties, int linkable_properties_length1);
FolksDummyFullPersona* folks_dummy_full_persona_construct (GType object_type, FolksDummyPersonaStore* store, const gchar* contact_id, gboolean is_user, gchar** linkable_properties, int linkable_properties_length1);
FolksDummyPersona* folks_dummy_persona_new (FolksDummyPersonaStore* store, const gchar* contact_id, gboolean is_user, gchar** linkable_properties, int linkable_properties_length1);
FolksDummyPersona* folks_dummy_persona_construct (GType object_type, FolksDummyPersonaStore* store, const gchar* contact_id, gboolean is_user, gchar** linkable_properties, int linkable_properties_length1);
static void folks_dummy_full_persona_real_change_web_service_addresses_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_web_service_addresses (FolksWebServiceDetails* base, GeeMultiMap* web_service_addresses, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_web_service_addresses_co (FolksDummyFullPersonaChangeWebServiceAddressesData* _data_);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
void folks_dummy_persona_change_property (FolksDummyPersona* self, const gchar* property_name, FolksDummyPersonaChangePropertyCallback callback, void* callback_target, GAsyncReadyCallback _callback_, gpointer _user_data_);
void folks_dummy_persona_change_property_finish (FolksDummyPersona* self, GAsyncResult* _res_);
static void __lambda8_ (Block3Data* _data3_);
void folks_dummy_full_persona_update_web_service_addresses (FolksDummyFullPersona* self, GeeMultiMap* web_service_addresses);
static void ___lambda8__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_web_service_addresses_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_local_ids_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_local_ids (FolksLocalIdDetails* base, GeeSet* local_ids, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_local_ids_co (FolksDummyFullPersonaChangeLocalIdsData* _data_);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static void __lambda9_ (Block4Data* _data4_);
void folks_dummy_full_persona_update_local_ids (FolksDummyFullPersona* self, GeeSet* local_ids);
static void ___lambda9__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_local_ids_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_postal_addresses_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_postal_addresses (FolksPostalAddressDetails* base, GeeSet* postal_addresses, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_postal_addresses_co (FolksDummyFullPersonaChangePostalAddressesData* _data_);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static void __lambda10_ (Block5Data* _data5_);
void folks_dummy_full_persona_update_postal_addresses (FolksDummyFullPersona* self, GeeSet* postal_addresses);
static void ___lambda10__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_postal_addresses_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_phone_numbers_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_phone_numbers (FolksPhoneDetails* base, GeeSet* phone_numbers, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_phone_numbers_co (FolksDummyFullPersonaChangePhoneNumbersData* _data_);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (void * _userdata_);
static void __lambda11_ (Block6Data* _data6_);
void folks_dummy_full_persona_update_phone_numbers (FolksDummyFullPersona* self, GeeSet* phone_numbers);
static void ___lambda11__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_phone_numbers_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_email_addresses_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_email_addresses (FolksEmailDetails* base, GeeSet* email_addresses, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_email_addresses_co (FolksDummyFullPersonaChangeEmailAddressesData* _data_);
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (void * _userdata_);
static void __lambda12_ (Block7Data* _data7_);
void folks_dummy_full_persona_update_email_addresses (FolksDummyFullPersona* self, GeeSet* email_addresses);
static void ___lambda12__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_email_addresses_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_notes_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_notes (FolksNoteDetails* base, GeeSet* notes, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_notes_co (FolksDummyFullPersonaChangeNotesData* _data_);
static Block8Data* block8_data_ref (Block8Data* _data8_);
static void block8_data_unref (void * _userdata_);
static void __lambda13_ (Block8Data* _data8_);
void folks_dummy_full_persona_update_notes (FolksDummyFullPersona* self, GeeSet* notes);
static void ___lambda13__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_notes_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_avatar_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_avatar (FolksAvatarDetails* base, GLoadableIcon* avatar, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_avatar_co (FolksDummyFullPersonaChangeAvatarData* _data_);
static Block9Data* block9_data_ref (Block9Data* _data9_);
static void block9_data_unref (void * _userdata_);
static void __lambda14_ (Block9Data* _data9_);
void folks_dummy_full_persona_update_avatar (FolksDummyFullPersona* self, GLoadableIcon* avatar);
static void ___lambda14__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_avatar_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_structured_name_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_structured_name (FolksNameDetails* base, FolksStructuredName* structured_name, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_structured_name_co (FolksDummyFullPersonaChangeStructuredNameData* _data_);
static Block10Data* block10_data_ref (Block10Data* _data10_);
static void block10_data_unref (void * _userdata_);
static void __lambda15_ (Block10Data* _data10_);
void folks_dummy_full_persona_update_structured_name (FolksDummyFullPersona* self, FolksStructuredName* structured_name);
static void ___lambda15__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_structured_name_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_full_name_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_full_name (FolksNameDetails* base, const gchar* full_name, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_full_name_co (FolksDummyFullPersonaChangeFullNameData* _data_);
static Block11Data* block11_data_ref (Block11Data* _data11_);
static void block11_data_unref (void * _userdata_);
static void __lambda16_ (Block11Data* _data11_);
void folks_dummy_full_persona_update_full_name (FolksDummyFullPersona* self, const gchar* full_name);
static void ___lambda16__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_full_name_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_nickname_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_nickname (FolksNameDetails* base, const gchar* nickname, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_nickname_co (FolksDummyFullPersonaChangeNicknameData* _data_);
static Block12Data* block12_data_ref (Block12Data* _data12_);
static void block12_data_unref (void * _userdata_);
static void __lambda17_ (Block12Data* _data12_);
void folks_dummy_full_persona_update_nickname (FolksDummyFullPersona* self, const gchar* nickname);
static void ___lambda17__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_nickname_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_gender_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_gender (FolksGenderDetails* base, FolksGender gender, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_gender_co (FolksDummyFullPersonaChangeGenderData* _data_);
static Block13Data* block13_data_ref (Block13Data* _data13_);
static void block13_data_unref (void * _userdata_);
static void __lambda18_ (Block13Data* _data13_);
void folks_dummy_full_persona_update_gender (FolksDummyFullPersona* self, FolksGender gender);
static void ___lambda18__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_gender_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_urls_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_urls (FolksUrlDetails* base, GeeSet* urls, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_urls_co (FolksDummyFullPersonaChangeUrlsData* _data_);
static Block14Data* block14_data_ref (Block14Data* _data14_);
static void block14_data_unref (void * _userdata_);
static void __lambda19_ (Block14Data* _data14_);
void folks_dummy_full_persona_update_urls (FolksDummyFullPersona* self, GeeSet* urls);
static void ___lambda19__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_urls_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_im_addresses_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_im_addresses (FolksImDetails* base, GeeMultiMap* im_addresses, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_im_addresses_co (FolksDummyFullPersonaChangeImAddressesData* _data_);
static Block15Data* block15_data_ref (Block15Data* _data15_);
static void block15_data_unref (void * _userdata_);
static void __lambda20_ (Block15Data* _data15_);
void folks_dummy_full_persona_update_im_addresses (FolksDummyFullPersona* self, GeeMultiMap* im_addresses);
static void ___lambda20__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_im_addresses_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_group_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_group (FolksGroupDetails* base, const gchar* group, gboolean is_member, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_group_co (FolksDummyFullPersonaChangeGroupData* _data_);
static void folks_dummy_full_persona_change_group_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_groups_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_groups (FolksGroupDetails* base, GeeSet* groups, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_groups_co (FolksDummyFullPersonaChangeGroupsData* _data_);
static Block16Data* block16_data_ref (Block16Data* _data16_);
static void block16_data_unref (void * _userdata_);
static void __lambda21_ (Block16Data* _data16_);
void folks_dummy_full_persona_update_groups (FolksDummyFullPersona* self, GeeSet* groups);
static void ___lambda21__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_groups_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_calendar_event_id_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_calendar_event_id (FolksBirthdayDetails* base, const gchar* calendar_event_id, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_calendar_event_id_co (FolksDummyFullPersonaChangeCalendarEventIdData* _data_);
static Block17Data* block17_data_ref (Block17Data* _data17_);
static void block17_data_unref (void * _userdata_);
static void __lambda22_ (Block17Data* _data17_);
void folks_dummy_full_persona_update_calendar_event_id (FolksDummyFullPersona* self, const gchar* calendar_event_id);
static void ___lambda22__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_calendar_event_id_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_birthday_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_birthday (FolksBirthdayDetails* base, GDateTime* bday, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_birthday_co (FolksDummyFullPersonaChangeBirthdayData* _data_);
static Block18Data* block18_data_ref (Block18Data* _data18_);
static void block18_data_unref (void * _userdata_);
static void __lambda23_ (Block18Data* _data18_);
void folks_dummy_full_persona_update_birthday (FolksDummyFullPersona* self, GDateTime* birthday);
static void ___lambda23__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_birthday_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_roles_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_roles (FolksRoleDetails* base, GeeSet* roles, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_roles_co (FolksDummyFullPersonaChangeRolesData* _data_);
static Block19Data* block19_data_ref (Block19Data* _data19_);
static void block19_data_unref (void * _userdata_);
static void __lambda24_ (Block19Data* _data19_);
void folks_dummy_full_persona_update_roles (FolksDummyFullPersona* self, GeeSet* roles);
static void ___lambda24__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_roles_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_is_favourite_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_is_favourite (FolksFavouriteDetails* base, gboolean is_favourite, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_is_favourite_co (FolksDummyFullPersonaChangeIsFavouriteData* _data_);
static Block20Data* block20_data_ref (Block20Data* _data20_);
static void block20_data_unref (void * _userdata_);
static void __lambda25_ (Block20Data* _data20_);
void folks_dummy_full_persona_update_is_favourite (FolksDummyFullPersona* self, gboolean is_favourite);
static void ___lambda25__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_is_favourite_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_dummy_full_persona_real_change_anti_links_data_free (gpointer _data);
static void folks_dummy_full_persona_real_change_anti_links (FolksAntiLinkable* base, GeeSet* anti_links, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean folks_dummy_full_persona_real_change_anti_links_co (FolksDummyFullPersonaChangeAntiLinksData* _data_);
static Block21Data* block21_data_ref (Block21Data* _data21_);
static void block21_data_unref (void * _userdata_);
static void __lambda26_ (Block21Data* _data21_);
void folks_dummy_full_persona_update_anti_links (FolksDummyFullPersona* self, GeeSet* anti_links);
static void ___lambda26__folks_dummy_persona_change_property_callback (gpointer self);
static void folks_dummy_full_persona_change_anti_links_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static GeeHashSet* _folks_dummy_full_persona_dup_to_hash_set (FolksDummyFullPersona* self, GType t_type, GBoxedCopyFunc t_dup_func, GDestroyNotify t_destroy_func, GeeSet* input_set);
static GeeHashMultiMap* _folks_dummy_full_persona_dup_to_hash_multi_map (FolksDummyFullPersona* self, GType s_type, GBoxedCopyFunc s_dup_func, GDestroyNotify s_destroy_func, GType t_type, GBoxedCopyFunc t_dup_func, GDestroyNotify t_destroy_func, GeeMultiMap* input_multi_map);
static GObject * folks_dummy_full_persona_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
void folks_dummy_persona_update_linkable_properties (FolksDummyPersona* self, gchar** linkable_properties, int linkable_properties_length1);
static void folks_dummy_full_persona_finalize (GObject * obj);
static void _vala_folks_dummy_full_persona_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_folks_dummy_full_persona_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);

static const gchar* FOLKS_DUMMY_FULL_PERSONA__default_linkable_properties[5] = {"im-addresses", "email-addresses", "local-ids", "web-service-addresses", NULL};

static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
	return result;
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
	return result;
}


/**
   * Create a new ‘full’ persona.
   *
   * Create a new persona for the {@link FolksDummy.PersonaStore} ``store``,
   * with the given construct-only properties.
   *
   * @param store the store which will contain the persona
   * @param contact_id a unique free-form string identifier for the persona
   * @param is_user ``true`` if the persona represents the user, ``false``
   * otherwise
   * @param linkable_properties an array of names of the properties which should
   * be used for linking this persona to others
   *
   * @since 0.9.7
   */
FolksDummyFullPersona* folks_dummy_full_persona_construct (GType object_type, FolksDummyPersonaStore* store, const gchar* contact_id, gboolean is_user, gchar** linkable_properties, int linkable_properties_length1) {
	FolksDummyFullPersona * self = NULL;
	FolksDummyPersonaStore* _tmp0_;
	const gchar* _tmp1_;
	gboolean _tmp2_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	g_return_val_if_fail (store != NULL, NULL);
	g_return_val_if_fail (contact_id != NULL, NULL);
	_tmp0_ = store;
	_tmp1_ = contact_id;
	_tmp2_ = is_user;
	_tmp3_ = linkable_properties;
	_tmp3__length1 = linkable_properties_length1;
	self = (FolksDummyFullPersona*) folks_dummy_persona_construct (object_type, _tmp0_, _tmp1_, _tmp2_, _tmp3_, _tmp3__length1);
	return self;
}


FolksDummyFullPersona* folks_dummy_full_persona_new (FolksDummyPersonaStore* store, const gchar* contact_id, gboolean is_user, gchar** linkable_properties, int linkable_properties_length1) {
	return folks_dummy_full_persona_construct (FOLKS_DUMMY_TYPE_FULL_PERSONA, store, contact_id, is_user, linkable_properties, linkable_properties_length1);
}


static void folks_dummy_full_persona_real_change_web_service_addresses_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeWebServiceAddressesData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeWebServiceAddressesData, _data_);
}


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


static void folks_dummy_full_persona_real_change_web_service_addresses (FolksWebServiceDetails* base, GeeMultiMap* web_service_addresses, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeWebServiceAddressesData* _data_;
	FolksDummyFullPersona* _tmp0_;
	GeeMultiMap* _tmp1_;
	GeeMultiMap* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeWebServiceAddressesData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_web_service_addresses);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_web_service_addresses_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = web_service_addresses;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (_data_->web_service_addresses);
	_data_->web_service_addresses = _tmp2_;
	folks_dummy_full_persona_real_change_web_service_addresses_co (_data_);
}


static void folks_dummy_full_persona_real_change_web_service_addresses_finish (FolksWebServiceDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeWebServiceAddressesData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block3Data* block3_data_ref (Block3Data* _data3_) {
	g_atomic_int_inc (&_data3_->_ref_count_);
	return _data3_;
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data3_->self;
		_g_object_unref0 (_data3_->web_service_addresses);
		_g_object_unref0 (self);
		g_slice_free (Block3Data, _data3_);
	}
}


static void __lambda8_ (Block3Data* _data3_) {
	FolksDummyFullPersona* self;
	GeeMultiMap* _tmp0_;
	self = _data3_->self;
	_tmp0_ = _data3_->web_service_addresses;
	folks_dummy_full_persona_update_web_service_addresses (self, _tmp0_);
}


static void ___lambda8__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda8_ (self);
}


static void folks_dummy_full_persona_change_web_service_addresses_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeWebServiceAddressesData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_web_service_addresses_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_web_service_addresses_co (FolksDummyFullPersonaChangeWebServiceAddressesData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data3_ = g_slice_new0 (Block3Data);
	_data_->_data3_->_ref_count_ = 1;
	_data_->_data3_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->web_service_addresses;
	_g_object_unref0 (_data_->_data3_->web_service_addresses);
	_data_->_data3_->web_service_addresses = _data_->_tmp0_;
	_data_->_data3_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "web-service-addresses", ___lambda8__folks_dummy_persona_change_property_callback, _data_->_data3_, folks_dummy_full_persona_change_web_service_addresses_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block3_data_unref (_data_->_data3_);
	_data_->_data3_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_local_ids_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeLocalIdsData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeLocalIdsData, _data_);
}


static void folks_dummy_full_persona_real_change_local_ids (FolksLocalIdDetails* base, GeeSet* local_ids, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeLocalIdsData* _data_;
	FolksDummyFullPersona* _tmp0_;
	GeeSet* _tmp1_;
	GeeSet* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeLocalIdsData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_local_ids);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_local_ids_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = local_ids;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (_data_->local_ids);
	_data_->local_ids = _tmp2_;
	folks_dummy_full_persona_real_change_local_ids_co (_data_);
}


static void folks_dummy_full_persona_real_change_local_ids_finish (FolksLocalIdDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeLocalIdsData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block4Data* block4_data_ref (Block4Data* _data4_) {
	g_atomic_int_inc (&_data4_->_ref_count_);
	return _data4_;
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data4_->self;
		_g_object_unref0 (_data4_->local_ids);
		_g_object_unref0 (self);
		g_slice_free (Block4Data, _data4_);
	}
}


static void __lambda9_ (Block4Data* _data4_) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = _data4_->self;
	_tmp0_ = _data4_->local_ids;
	folks_dummy_full_persona_update_local_ids (self, _tmp0_);
}


static void ___lambda9__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda9_ (self);
}


static void folks_dummy_full_persona_change_local_ids_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeLocalIdsData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_local_ids_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_local_ids_co (FolksDummyFullPersonaChangeLocalIdsData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data4_ = g_slice_new0 (Block4Data);
	_data_->_data4_->_ref_count_ = 1;
	_data_->_data4_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->local_ids;
	_g_object_unref0 (_data_->_data4_->local_ids);
	_data_->_data4_->local_ids = _data_->_tmp0_;
	_data_->_data4_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "local-ids", ___lambda9__folks_dummy_persona_change_property_callback, _data_->_data4_, folks_dummy_full_persona_change_local_ids_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block4_data_unref (_data_->_data4_);
	_data_->_data4_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_postal_addresses_data_free (gpointer _data) {
	FolksDummyFullPersonaChangePostalAddressesData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangePostalAddressesData, _data_);
}


static void folks_dummy_full_persona_real_change_postal_addresses (FolksPostalAddressDetails* base, GeeSet* postal_addresses, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangePostalAddressesData* _data_;
	FolksDummyFullPersona* _tmp0_;
	GeeSet* _tmp1_;
	GeeSet* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangePostalAddressesData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_postal_addresses);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_postal_addresses_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = postal_addresses;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (_data_->postal_addresses);
	_data_->postal_addresses = _tmp2_;
	folks_dummy_full_persona_real_change_postal_addresses_co (_data_);
}


static void folks_dummy_full_persona_real_change_postal_addresses_finish (FolksPostalAddressDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangePostalAddressesData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block5Data* block5_data_ref (Block5Data* _data5_) {
	g_atomic_int_inc (&_data5_->_ref_count_);
	return _data5_;
}


static void block5_data_unref (void * _userdata_) {
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data5_->self;
		_g_object_unref0 (_data5_->postal_addresses);
		_g_object_unref0 (self);
		g_slice_free (Block5Data, _data5_);
	}
}


static void __lambda10_ (Block5Data* _data5_) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = _data5_->self;
	_tmp0_ = _data5_->postal_addresses;
	folks_dummy_full_persona_update_postal_addresses (self, _tmp0_);
}


static void ___lambda10__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda10_ (self);
}


static void folks_dummy_full_persona_change_postal_addresses_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangePostalAddressesData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_postal_addresses_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_postal_addresses_co (FolksDummyFullPersonaChangePostalAddressesData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data5_ = g_slice_new0 (Block5Data);
	_data_->_data5_->_ref_count_ = 1;
	_data_->_data5_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->postal_addresses;
	_g_object_unref0 (_data_->_data5_->postal_addresses);
	_data_->_data5_->postal_addresses = _data_->_tmp0_;
	_data_->_data5_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "postal-addresses", ___lambda10__folks_dummy_persona_change_property_callback, _data_->_data5_, folks_dummy_full_persona_change_postal_addresses_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block5_data_unref (_data_->_data5_);
	_data_->_data5_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_phone_numbers_data_free (gpointer _data) {
	FolksDummyFullPersonaChangePhoneNumbersData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangePhoneNumbersData, _data_);
}


static void folks_dummy_full_persona_real_change_phone_numbers (FolksPhoneDetails* base, GeeSet* phone_numbers, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangePhoneNumbersData* _data_;
	FolksDummyFullPersona* _tmp0_;
	GeeSet* _tmp1_;
	GeeSet* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangePhoneNumbersData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_phone_numbers);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_phone_numbers_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = phone_numbers;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (_data_->phone_numbers);
	_data_->phone_numbers = _tmp2_;
	folks_dummy_full_persona_real_change_phone_numbers_co (_data_);
}


static void folks_dummy_full_persona_real_change_phone_numbers_finish (FolksPhoneDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangePhoneNumbersData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block6Data* block6_data_ref (Block6Data* _data6_) {
	g_atomic_int_inc (&_data6_->_ref_count_);
	return _data6_;
}


static void block6_data_unref (void * _userdata_) {
	Block6Data* _data6_;
	_data6_ = (Block6Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data6_->self;
		_g_object_unref0 (_data6_->phone_numbers);
		_g_object_unref0 (self);
		g_slice_free (Block6Data, _data6_);
	}
}


static void __lambda11_ (Block6Data* _data6_) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = _data6_->self;
	_tmp0_ = _data6_->phone_numbers;
	folks_dummy_full_persona_update_phone_numbers (self, _tmp0_);
}


static void ___lambda11__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda11_ (self);
}


static void folks_dummy_full_persona_change_phone_numbers_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangePhoneNumbersData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_phone_numbers_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_phone_numbers_co (FolksDummyFullPersonaChangePhoneNumbersData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data6_ = g_slice_new0 (Block6Data);
	_data_->_data6_->_ref_count_ = 1;
	_data_->_data6_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->phone_numbers;
	_g_object_unref0 (_data_->_data6_->phone_numbers);
	_data_->_data6_->phone_numbers = _data_->_tmp0_;
	_data_->_data6_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "phone-numbers", ___lambda11__folks_dummy_persona_change_property_callback, _data_->_data6_, folks_dummy_full_persona_change_phone_numbers_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block6_data_unref (_data_->_data6_);
	_data_->_data6_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_email_addresses_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeEmailAddressesData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeEmailAddressesData, _data_);
}


static void folks_dummy_full_persona_real_change_email_addresses (FolksEmailDetails* base, GeeSet* email_addresses, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeEmailAddressesData* _data_;
	FolksDummyFullPersona* _tmp0_;
	GeeSet* _tmp1_;
	GeeSet* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeEmailAddressesData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_email_addresses);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_email_addresses_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = email_addresses;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (_data_->email_addresses);
	_data_->email_addresses = _tmp2_;
	folks_dummy_full_persona_real_change_email_addresses_co (_data_);
}


static void folks_dummy_full_persona_real_change_email_addresses_finish (FolksEmailDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeEmailAddressesData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block7Data* block7_data_ref (Block7Data* _data7_) {
	g_atomic_int_inc (&_data7_->_ref_count_);
	return _data7_;
}


static void block7_data_unref (void * _userdata_) {
	Block7Data* _data7_;
	_data7_ = (Block7Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data7_->self;
		_g_object_unref0 (_data7_->email_addresses);
		_g_object_unref0 (self);
		g_slice_free (Block7Data, _data7_);
	}
}


static void __lambda12_ (Block7Data* _data7_) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = _data7_->self;
	_tmp0_ = _data7_->email_addresses;
	folks_dummy_full_persona_update_email_addresses (self, _tmp0_);
}


static void ___lambda12__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda12_ (self);
}


static void folks_dummy_full_persona_change_email_addresses_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeEmailAddressesData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_email_addresses_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_email_addresses_co (FolksDummyFullPersonaChangeEmailAddressesData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data7_ = g_slice_new0 (Block7Data);
	_data_->_data7_->_ref_count_ = 1;
	_data_->_data7_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->email_addresses;
	_g_object_unref0 (_data_->_data7_->email_addresses);
	_data_->_data7_->email_addresses = _data_->_tmp0_;
	_data_->_data7_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "email-addresses", ___lambda12__folks_dummy_persona_change_property_callback, _data_->_data7_, folks_dummy_full_persona_change_email_addresses_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block7_data_unref (_data_->_data7_);
	_data_->_data7_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_notes_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeNotesData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeNotesData, _data_);
}


static void folks_dummy_full_persona_real_change_notes (FolksNoteDetails* base, GeeSet* notes, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeNotesData* _data_;
	FolksDummyFullPersona* _tmp0_;
	GeeSet* _tmp1_;
	GeeSet* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeNotesData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_notes);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_notes_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = notes;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (_data_->notes);
	_data_->notes = _tmp2_;
	folks_dummy_full_persona_real_change_notes_co (_data_);
}


static void folks_dummy_full_persona_real_change_notes_finish (FolksNoteDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeNotesData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block8Data* block8_data_ref (Block8Data* _data8_) {
	g_atomic_int_inc (&_data8_->_ref_count_);
	return _data8_;
}


static void block8_data_unref (void * _userdata_) {
	Block8Data* _data8_;
	_data8_ = (Block8Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data8_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data8_->self;
		_g_object_unref0 (_data8_->notes);
		_g_object_unref0 (self);
		g_slice_free (Block8Data, _data8_);
	}
}


static void __lambda13_ (Block8Data* _data8_) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = _data8_->self;
	_tmp0_ = _data8_->notes;
	folks_dummy_full_persona_update_notes (self, _tmp0_);
}


static void ___lambda13__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda13_ (self);
}


static void folks_dummy_full_persona_change_notes_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeNotesData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_notes_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_notes_co (FolksDummyFullPersonaChangeNotesData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data8_ = g_slice_new0 (Block8Data);
	_data_->_data8_->_ref_count_ = 1;
	_data_->_data8_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->notes;
	_g_object_unref0 (_data_->_data8_->notes);
	_data_->_data8_->notes = _data_->_tmp0_;
	_data_->_data8_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "notes", ___lambda13__folks_dummy_persona_change_property_callback, _data_->_data8_, folks_dummy_full_persona_change_notes_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block8_data_unref (_data_->_data8_);
	_data_->_data8_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_avatar_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeAvatarData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeAvatarData, _data_);
}


static void folks_dummy_full_persona_real_change_avatar (FolksAvatarDetails* base, GLoadableIcon* avatar, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeAvatarData* _data_;
	FolksDummyFullPersona* _tmp0_;
	GLoadableIcon* _tmp1_;
	GLoadableIcon* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeAvatarData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_avatar);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_avatar_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = avatar;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (_data_->avatar);
	_data_->avatar = _tmp2_;
	folks_dummy_full_persona_real_change_avatar_co (_data_);
}


static void folks_dummy_full_persona_real_change_avatar_finish (FolksAvatarDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeAvatarData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block9Data* block9_data_ref (Block9Data* _data9_) {
	g_atomic_int_inc (&_data9_->_ref_count_);
	return _data9_;
}


static void block9_data_unref (void * _userdata_) {
	Block9Data* _data9_;
	_data9_ = (Block9Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data9_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data9_->self;
		_g_object_unref0 (_data9_->avatar);
		_g_object_unref0 (self);
		g_slice_free (Block9Data, _data9_);
	}
}


static void __lambda14_ (Block9Data* _data9_) {
	FolksDummyFullPersona* self;
	GLoadableIcon* _tmp0_;
	self = _data9_->self;
	_tmp0_ = _data9_->avatar;
	folks_dummy_full_persona_update_avatar (self, _tmp0_);
}


static void ___lambda14__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda14_ (self);
}


static void folks_dummy_full_persona_change_avatar_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeAvatarData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_avatar_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_avatar_co (FolksDummyFullPersonaChangeAvatarData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data9_ = g_slice_new0 (Block9Data);
	_data_->_data9_->_ref_count_ = 1;
	_data_->_data9_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->avatar;
	_g_object_unref0 (_data_->_data9_->avatar);
	_data_->_data9_->avatar = _data_->_tmp0_;
	_data_->_data9_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "avatar", ___lambda14__folks_dummy_persona_change_property_callback, _data_->_data9_, folks_dummy_full_persona_change_avatar_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block9_data_unref (_data_->_data9_);
	_data_->_data9_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_structured_name_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeStructuredNameData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeStructuredNameData, _data_);
}


static void folks_dummy_full_persona_real_change_structured_name (FolksNameDetails* base, FolksStructuredName* structured_name, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeStructuredNameData* _data_;
	FolksDummyFullPersona* _tmp0_;
	FolksStructuredName* _tmp1_;
	FolksStructuredName* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeStructuredNameData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_structured_name);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_structured_name_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = structured_name;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (_data_->structured_name);
	_data_->structured_name = _tmp2_;
	folks_dummy_full_persona_real_change_structured_name_co (_data_);
}


static void folks_dummy_full_persona_real_change_structured_name_finish (FolksNameDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeStructuredNameData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block10Data* block10_data_ref (Block10Data* _data10_) {
	g_atomic_int_inc (&_data10_->_ref_count_);
	return _data10_;
}


static void block10_data_unref (void * _userdata_) {
	Block10Data* _data10_;
	_data10_ = (Block10Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data10_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data10_->self;
		_g_object_unref0 (_data10_->structured_name);
		_g_object_unref0 (self);
		g_slice_free (Block10Data, _data10_);
	}
}


static void __lambda15_ (Block10Data* _data10_) {
	FolksDummyFullPersona* self;
	FolksStructuredName* _tmp0_;
	self = _data10_->self;
	_tmp0_ = _data10_->structured_name;
	folks_dummy_full_persona_update_structured_name (self, _tmp0_);
}


static void ___lambda15__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda15_ (self);
}


static void folks_dummy_full_persona_change_structured_name_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeStructuredNameData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_structured_name_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_structured_name_co (FolksDummyFullPersonaChangeStructuredNameData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data10_ = g_slice_new0 (Block10Data);
	_data_->_data10_->_ref_count_ = 1;
	_data_->_data10_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->structured_name;
	_g_object_unref0 (_data_->_data10_->structured_name);
	_data_->_data10_->structured_name = _data_->_tmp0_;
	_data_->_data10_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "structured-name", ___lambda15__folks_dummy_persona_change_property_callback, _data_->_data10_, folks_dummy_full_persona_change_structured_name_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block10_data_unref (_data_->_data10_);
	_data_->_data10_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_full_name_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeFullNameData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeFullNameData, _data_);
}


static void folks_dummy_full_persona_real_change_full_name (FolksNameDetails* base, const gchar* full_name, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeFullNameData* _data_;
	FolksDummyFullPersona* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeFullNameData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_full_name);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_full_name_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = full_name;
	_tmp2_ = g_strdup (_tmp1_);
	_g_free0 (_data_->full_name);
	_data_->full_name = _tmp2_;
	folks_dummy_full_persona_real_change_full_name_co (_data_);
}


static void folks_dummy_full_persona_real_change_full_name_finish (FolksNameDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeFullNameData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block11Data* block11_data_ref (Block11Data* _data11_) {
	g_atomic_int_inc (&_data11_->_ref_count_);
	return _data11_;
}


static void block11_data_unref (void * _userdata_) {
	Block11Data* _data11_;
	_data11_ = (Block11Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data11_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data11_->self;
		_g_free0 (_data11_->full_name);
		_g_object_unref0 (self);
		g_slice_free (Block11Data, _data11_);
	}
}


static void __lambda16_ (Block11Data* _data11_) {
	FolksDummyFullPersona* self;
	const gchar* _tmp0_;
	self = _data11_->self;
	_tmp0_ = _data11_->full_name;
	folks_dummy_full_persona_update_full_name (self, _tmp0_);
}


static void ___lambda16__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda16_ (self);
}


static void folks_dummy_full_persona_change_full_name_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeFullNameData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_full_name_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_full_name_co (FolksDummyFullPersonaChangeFullNameData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data11_ = g_slice_new0 (Block11Data);
	_data_->_data11_->_ref_count_ = 1;
	_data_->_data11_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->full_name;
	_g_free0 (_data_->_data11_->full_name);
	_data_->_data11_->full_name = _data_->_tmp0_;
	_data_->_data11_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "full-name", ___lambda16__folks_dummy_persona_change_property_callback, _data_->_data11_, folks_dummy_full_persona_change_full_name_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block11_data_unref (_data_->_data11_);
	_data_->_data11_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_nickname_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeNicknameData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeNicknameData, _data_);
}


static void folks_dummy_full_persona_real_change_nickname (FolksNameDetails* base, const gchar* nickname, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeNicknameData* _data_;
	FolksDummyFullPersona* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeNicknameData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_nickname);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_nickname_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = nickname;
	_tmp2_ = g_strdup (_tmp1_);
	_g_free0 (_data_->nickname);
	_data_->nickname = _tmp2_;
	folks_dummy_full_persona_real_change_nickname_co (_data_);
}


static void folks_dummy_full_persona_real_change_nickname_finish (FolksNameDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeNicknameData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block12Data* block12_data_ref (Block12Data* _data12_) {
	g_atomic_int_inc (&_data12_->_ref_count_);
	return _data12_;
}


static void block12_data_unref (void * _userdata_) {
	Block12Data* _data12_;
	_data12_ = (Block12Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data12_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data12_->self;
		_g_free0 (_data12_->nickname);
		_g_object_unref0 (self);
		g_slice_free (Block12Data, _data12_);
	}
}


static void __lambda17_ (Block12Data* _data12_) {
	FolksDummyFullPersona* self;
	const gchar* _tmp0_;
	self = _data12_->self;
	_tmp0_ = _data12_->nickname;
	folks_dummy_full_persona_update_nickname (self, _tmp0_);
}


static void ___lambda17__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda17_ (self);
}


static void folks_dummy_full_persona_change_nickname_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeNicknameData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_nickname_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_nickname_co (FolksDummyFullPersonaChangeNicknameData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data12_ = g_slice_new0 (Block12Data);
	_data_->_data12_->_ref_count_ = 1;
	_data_->_data12_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->nickname;
	_g_free0 (_data_->_data12_->nickname);
	_data_->_data12_->nickname = _data_->_tmp0_;
	_data_->_data12_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "nickname", ___lambda17__folks_dummy_persona_change_property_callback, _data_->_data12_, folks_dummy_full_persona_change_nickname_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block12_data_unref (_data_->_data12_);
	_data_->_data12_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_gender_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeGenderData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeGenderData, _data_);
}


static void folks_dummy_full_persona_real_change_gender (FolksGenderDetails* base, FolksGender gender, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeGenderData* _data_;
	FolksDummyFullPersona* _tmp0_;
	FolksGender _tmp1_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeGenderData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_gender);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_gender_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = gender;
	_data_->gender = _tmp1_;
	folks_dummy_full_persona_real_change_gender_co (_data_);
}


static void folks_dummy_full_persona_real_change_gender_finish (FolksGenderDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeGenderData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block13Data* block13_data_ref (Block13Data* _data13_) {
	g_atomic_int_inc (&_data13_->_ref_count_);
	return _data13_;
}


static void block13_data_unref (void * _userdata_) {
	Block13Data* _data13_;
	_data13_ = (Block13Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data13_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data13_->self;
		_g_object_unref0 (self);
		g_slice_free (Block13Data, _data13_);
	}
}


static void __lambda18_ (Block13Data* _data13_) {
	FolksDummyFullPersona* self;
	FolksGender _tmp0_;
	self = _data13_->self;
	_tmp0_ = _data13_->gender;
	folks_dummy_full_persona_update_gender (self, _tmp0_);
}


static void ___lambda18__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda18_ (self);
}


static void folks_dummy_full_persona_change_gender_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeGenderData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_gender_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_gender_co (FolksDummyFullPersonaChangeGenderData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data13_ = g_slice_new0 (Block13Data);
	_data_->_data13_->_ref_count_ = 1;
	_data_->_data13_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->gender;
	_data_->_data13_->gender = _data_->_tmp0_;
	_data_->_data13_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "gender", ___lambda18__folks_dummy_persona_change_property_callback, _data_->_data13_, folks_dummy_full_persona_change_gender_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block13_data_unref (_data_->_data13_);
	_data_->_data13_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_urls_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeUrlsData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeUrlsData, _data_);
}


static void folks_dummy_full_persona_real_change_urls (FolksUrlDetails* base, GeeSet* urls, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeUrlsData* _data_;
	FolksDummyFullPersona* _tmp0_;
	GeeSet* _tmp1_;
	GeeSet* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeUrlsData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_urls);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_urls_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = urls;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (_data_->urls);
	_data_->urls = _tmp2_;
	folks_dummy_full_persona_real_change_urls_co (_data_);
}


static void folks_dummy_full_persona_real_change_urls_finish (FolksUrlDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeUrlsData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block14Data* block14_data_ref (Block14Data* _data14_) {
	g_atomic_int_inc (&_data14_->_ref_count_);
	return _data14_;
}


static void block14_data_unref (void * _userdata_) {
	Block14Data* _data14_;
	_data14_ = (Block14Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data14_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data14_->self;
		_g_object_unref0 (_data14_->urls);
		_g_object_unref0 (self);
		g_slice_free (Block14Data, _data14_);
	}
}


static void __lambda19_ (Block14Data* _data14_) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = _data14_->self;
	_tmp0_ = _data14_->urls;
	folks_dummy_full_persona_update_urls (self, _tmp0_);
}


static void ___lambda19__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda19_ (self);
}


static void folks_dummy_full_persona_change_urls_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeUrlsData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_urls_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_urls_co (FolksDummyFullPersonaChangeUrlsData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data14_ = g_slice_new0 (Block14Data);
	_data_->_data14_->_ref_count_ = 1;
	_data_->_data14_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->urls;
	_g_object_unref0 (_data_->_data14_->urls);
	_data_->_data14_->urls = _data_->_tmp0_;
	_data_->_data14_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "urls", ___lambda19__folks_dummy_persona_change_property_callback, _data_->_data14_, folks_dummy_full_persona_change_urls_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block14_data_unref (_data_->_data14_);
	_data_->_data14_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_im_addresses_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeImAddressesData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeImAddressesData, _data_);
}


static void folks_dummy_full_persona_real_change_im_addresses (FolksImDetails* base, GeeMultiMap* im_addresses, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeImAddressesData* _data_;
	FolksDummyFullPersona* _tmp0_;
	GeeMultiMap* _tmp1_;
	GeeMultiMap* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeImAddressesData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_im_addresses);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_im_addresses_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = im_addresses;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (_data_->im_addresses);
	_data_->im_addresses = _tmp2_;
	folks_dummy_full_persona_real_change_im_addresses_co (_data_);
}


static void folks_dummy_full_persona_real_change_im_addresses_finish (FolksImDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeImAddressesData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block15Data* block15_data_ref (Block15Data* _data15_) {
	g_atomic_int_inc (&_data15_->_ref_count_);
	return _data15_;
}


static void block15_data_unref (void * _userdata_) {
	Block15Data* _data15_;
	_data15_ = (Block15Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data15_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data15_->self;
		_g_object_unref0 (_data15_->im_addresses);
		_g_object_unref0 (self);
		g_slice_free (Block15Data, _data15_);
	}
}


static void __lambda20_ (Block15Data* _data15_) {
	FolksDummyFullPersona* self;
	GeeMultiMap* _tmp0_;
	self = _data15_->self;
	_tmp0_ = _data15_->im_addresses;
	folks_dummy_full_persona_update_im_addresses (self, _tmp0_);
}


static void ___lambda20__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda20_ (self);
}


static void folks_dummy_full_persona_change_im_addresses_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeImAddressesData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_im_addresses_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_im_addresses_co (FolksDummyFullPersonaChangeImAddressesData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data15_ = g_slice_new0 (Block15Data);
	_data_->_data15_->_ref_count_ = 1;
	_data_->_data15_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->im_addresses;
	_g_object_unref0 (_data_->_data15_->im_addresses);
	_data_->_data15_->im_addresses = _data_->_tmp0_;
	_data_->_data15_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "im-addresses", ___lambda20__folks_dummy_persona_change_property_callback, _data_->_data15_, folks_dummy_full_persona_change_im_addresses_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block15_data_unref (_data_->_data15_);
	_data_->_data15_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_group_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeGroupData* _data_;
	_data_ = _data;
	_g_free0 (_data_->group);
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeGroupData, _data_);
}


static void folks_dummy_full_persona_real_change_group (FolksGroupDetails* base, const gchar* group, gboolean is_member, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeGroupData* _data_;
	FolksDummyFullPersona* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gboolean _tmp3_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeGroupData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_group);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_group_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = group;
	_tmp2_ = g_strdup (_tmp1_);
	_g_free0 (_data_->group);
	_data_->group = _tmp2_;
	_tmp3_ = is_member;
	_data_->is_member = _tmp3_;
	folks_dummy_full_persona_real_change_group_co (_data_);
}


static void folks_dummy_full_persona_real_change_group_finish (FolksGroupDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeGroupData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static void folks_dummy_full_persona_change_group_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeGroupData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_group_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_group_co (FolksDummyFullPersonaChangeGroupData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp2_ = _data_->is_member;
	if (_data_->_tmp2_ == TRUE) {
		_data_->_tmp3_ = _data_->self->priv->_groups;
		_data_->_tmp4_ = _data_->group;
		_data_->_tmp5_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _data_->_tmp3_, _data_->_tmp4_);
		_data_->_tmp1_ = _data_->_tmp5_ == TRUE;
	} else {
		_data_->_tmp1_ = FALSE;
	}
	if (_data_->_tmp1_) {
		_data_->_tmp0_ = TRUE;
	} else {
		_data_->_tmp7_ = _data_->is_member;
		if (_data_->_tmp7_ == FALSE) {
			_data_->_tmp8_ = _data_->self->priv->_groups;
			_data_->_tmp9_ = _data_->group;
			_data_->_tmp10_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _data_->_tmp8_, _data_->_tmp9_);
			_data_->_tmp6_ = _data_->_tmp10_ == FALSE;
		} else {
			_data_->_tmp6_ = FALSE;
		}
		_data_->_tmp0_ = _data_->_tmp6_;
	}
	if (_data_->_tmp0_) {
		if (_data_->_state_ == 0) {
			g_simple_async_result_complete_in_idle (_data_->_async_result);
		} else {
			g_simple_async_result_complete (_data_->_async_result);
		}
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp11_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
	_data_->new_groups = _data_->_tmp11_;
	{
		_data_->_tmp12_ = _data_->self->priv->_groups;
		_data_->_tmp13_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _data_->_tmp12_);
		_data_->_category_name_it = _data_->_tmp13_;
		while (TRUE) {
			_data_->_tmp14_ = _data_->_category_name_it;
			_data_->_tmp15_ = gee_iterator_next (_data_->_tmp14_);
			if (!_data_->_tmp15_) {
				break;
			}
			_data_->_tmp16_ = _data_->_category_name_it;
			_data_->_tmp17_ = gee_iterator_get (_data_->_tmp16_);
			_data_->category_name = (gchar*) _data_->_tmp17_;
			_data_->_tmp18_ = _data_->new_groups;
			_data_->_tmp19_ = _data_->category_name;
			gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp18_, _data_->_tmp19_);
			_g_free0 (_data_->category_name);
		}
		_g_object_unref0 (_data_->_category_name_it);
	}
	_data_->_tmp20_ = _data_->is_member;
	if (_data_->_tmp20_ == FALSE) {
		_data_->_tmp21_ = _data_->new_groups;
		_data_->_tmp22_ = _data_->group;
		gee_abstract_collection_remove ((GeeAbstractCollection*) _data_->_tmp21_, _data_->_tmp22_);
	} else {
		_data_->_tmp23_ = _data_->new_groups;
		_data_->_tmp24_ = _data_->group;
		gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp23_, _data_->_tmp24_);
	}
	_data_->_tmp25_ = _data_->new_groups;
	_data_->_state_ = 1;
	folks_group_details_change_groups ((FolksGroupDetails*) _data_->self, (GeeSet*) _data_->_tmp25_, folks_dummy_full_persona_change_group_ready, _data_);
	return FALSE;
	_state_1:
	folks_group_details_change_groups_finish ((FolksGroupDetails*) _data_->self, _data_->_res_, &_data_->_inner_error_);
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
		g_simple_async_result_take_error (_data_->_async_result, _data_->_inner_error_);
		_g_object_unref0 (_data_->new_groups);
		if (_data_->_state_ == 0) {
			g_simple_async_result_complete_in_idle (_data_->_async_result);
		} else {
			g_simple_async_result_complete (_data_->_async_result);
		}
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_g_object_unref0 (_data_->new_groups);
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_groups_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeGroupsData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeGroupsData, _data_);
}


static void folks_dummy_full_persona_real_change_groups (FolksGroupDetails* base, GeeSet* groups, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeGroupsData* _data_;
	FolksDummyFullPersona* _tmp0_;
	GeeSet* _tmp1_;
	GeeSet* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeGroupsData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_groups);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_groups_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = groups;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (_data_->groups);
	_data_->groups = _tmp2_;
	folks_dummy_full_persona_real_change_groups_co (_data_);
}


static void folks_dummy_full_persona_real_change_groups_finish (FolksGroupDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeGroupsData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block16Data* block16_data_ref (Block16Data* _data16_) {
	g_atomic_int_inc (&_data16_->_ref_count_);
	return _data16_;
}


static void block16_data_unref (void * _userdata_) {
	Block16Data* _data16_;
	_data16_ = (Block16Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data16_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data16_->self;
		_g_object_unref0 (_data16_->groups);
		_g_object_unref0 (self);
		g_slice_free (Block16Data, _data16_);
	}
}


static void __lambda21_ (Block16Data* _data16_) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = _data16_->self;
	_tmp0_ = _data16_->groups;
	folks_dummy_full_persona_update_groups (self, _tmp0_);
}


static void ___lambda21__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda21_ (self);
}


static void folks_dummy_full_persona_change_groups_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeGroupsData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_groups_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_groups_co (FolksDummyFullPersonaChangeGroupsData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data16_ = g_slice_new0 (Block16Data);
	_data_->_data16_->_ref_count_ = 1;
	_data_->_data16_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->groups;
	_g_object_unref0 (_data_->_data16_->groups);
	_data_->_data16_->groups = _data_->_tmp0_;
	_data_->_data16_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "groups", ___lambda21__folks_dummy_persona_change_property_callback, _data_->_data16_, folks_dummy_full_persona_change_groups_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block16_data_unref (_data_->_data16_);
	_data_->_data16_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_calendar_event_id_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeCalendarEventIdData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeCalendarEventIdData, _data_);
}


static void folks_dummy_full_persona_real_change_calendar_event_id (FolksBirthdayDetails* base, const gchar* calendar_event_id, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeCalendarEventIdData* _data_;
	FolksDummyFullPersona* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeCalendarEventIdData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_calendar_event_id);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_calendar_event_id_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = calendar_event_id;
	_tmp2_ = g_strdup (_tmp1_);
	_g_free0 (_data_->calendar_event_id);
	_data_->calendar_event_id = _tmp2_;
	folks_dummy_full_persona_real_change_calendar_event_id_co (_data_);
}


static void folks_dummy_full_persona_real_change_calendar_event_id_finish (FolksBirthdayDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeCalendarEventIdData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block17Data* block17_data_ref (Block17Data* _data17_) {
	g_atomic_int_inc (&_data17_->_ref_count_);
	return _data17_;
}


static void block17_data_unref (void * _userdata_) {
	Block17Data* _data17_;
	_data17_ = (Block17Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data17_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data17_->self;
		_g_free0 (_data17_->calendar_event_id);
		_g_object_unref0 (self);
		g_slice_free (Block17Data, _data17_);
	}
}


static void __lambda22_ (Block17Data* _data17_) {
	FolksDummyFullPersona* self;
	const gchar* _tmp0_;
	self = _data17_->self;
	_tmp0_ = _data17_->calendar_event_id;
	folks_dummy_full_persona_update_calendar_event_id (self, _tmp0_);
}


static void ___lambda22__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda22_ (self);
}


static void folks_dummy_full_persona_change_calendar_event_id_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeCalendarEventIdData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_calendar_event_id_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_calendar_event_id_co (FolksDummyFullPersonaChangeCalendarEventIdData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data17_ = g_slice_new0 (Block17Data);
	_data_->_data17_->_ref_count_ = 1;
	_data_->_data17_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->calendar_event_id;
	_g_free0 (_data_->_data17_->calendar_event_id);
	_data_->_data17_->calendar_event_id = _data_->_tmp0_;
	_data_->_data17_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "calendar-event-id", ___lambda22__folks_dummy_persona_change_property_callback, _data_->_data17_, folks_dummy_full_persona_change_calendar_event_id_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block17_data_unref (_data_->_data17_);
	_data_->_data17_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_birthday_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeBirthdayData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeBirthdayData, _data_);
}


static gpointer _g_date_time_ref0 (gpointer self) {
	return self ? g_date_time_ref (self) : NULL;
}


static void folks_dummy_full_persona_real_change_birthday (FolksBirthdayDetails* base, GDateTime* bday, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeBirthdayData* _data_;
	FolksDummyFullPersona* _tmp0_;
	GDateTime* _tmp1_;
	GDateTime* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeBirthdayData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_birthday);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_birthday_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = bday;
	_tmp2_ = _g_date_time_ref0 (_tmp1_);
	_g_date_time_unref0 (_data_->bday);
	_data_->bday = _tmp2_;
	folks_dummy_full_persona_real_change_birthday_co (_data_);
}


static void folks_dummy_full_persona_real_change_birthday_finish (FolksBirthdayDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeBirthdayData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block18Data* block18_data_ref (Block18Data* _data18_) {
	g_atomic_int_inc (&_data18_->_ref_count_);
	return _data18_;
}


static void block18_data_unref (void * _userdata_) {
	Block18Data* _data18_;
	_data18_ = (Block18Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data18_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data18_->self;
		_g_date_time_unref0 (_data18_->bday);
		_g_object_unref0 (self);
		g_slice_free (Block18Data, _data18_);
	}
}


static void __lambda23_ (Block18Data* _data18_) {
	FolksDummyFullPersona* self;
	GDateTime* _tmp0_;
	self = _data18_->self;
	_tmp0_ = _data18_->bday;
	folks_dummy_full_persona_update_birthday (self, _tmp0_);
}


static void ___lambda23__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda23_ (self);
}


static void folks_dummy_full_persona_change_birthday_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeBirthdayData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_birthday_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_birthday_co (FolksDummyFullPersonaChangeBirthdayData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data18_ = g_slice_new0 (Block18Data);
	_data_->_data18_->_ref_count_ = 1;
	_data_->_data18_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->bday;
	_g_date_time_unref0 (_data_->_data18_->bday);
	_data_->_data18_->bday = _data_->_tmp0_;
	_data_->_data18_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "birthday", ___lambda23__folks_dummy_persona_change_property_callback, _data_->_data18_, folks_dummy_full_persona_change_birthday_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block18_data_unref (_data_->_data18_);
	_data_->_data18_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_roles_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeRolesData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeRolesData, _data_);
}


static void folks_dummy_full_persona_real_change_roles (FolksRoleDetails* base, GeeSet* roles, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeRolesData* _data_;
	FolksDummyFullPersona* _tmp0_;
	GeeSet* _tmp1_;
	GeeSet* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeRolesData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_roles);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_roles_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = roles;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (_data_->roles);
	_data_->roles = _tmp2_;
	folks_dummy_full_persona_real_change_roles_co (_data_);
}


static void folks_dummy_full_persona_real_change_roles_finish (FolksRoleDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeRolesData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block19Data* block19_data_ref (Block19Data* _data19_) {
	g_atomic_int_inc (&_data19_->_ref_count_);
	return _data19_;
}


static void block19_data_unref (void * _userdata_) {
	Block19Data* _data19_;
	_data19_ = (Block19Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data19_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data19_->self;
		_g_object_unref0 (_data19_->roles);
		_g_object_unref0 (self);
		g_slice_free (Block19Data, _data19_);
	}
}


static void __lambda24_ (Block19Data* _data19_) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = _data19_->self;
	_tmp0_ = _data19_->roles;
	folks_dummy_full_persona_update_roles (self, _tmp0_);
}


static void ___lambda24__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda24_ (self);
}


static void folks_dummy_full_persona_change_roles_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeRolesData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_roles_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_roles_co (FolksDummyFullPersonaChangeRolesData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data19_ = g_slice_new0 (Block19Data);
	_data_->_data19_->_ref_count_ = 1;
	_data_->_data19_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->roles;
	_g_object_unref0 (_data_->_data19_->roles);
	_data_->_data19_->roles = _data_->_tmp0_;
	_data_->_data19_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "roles", ___lambda24__folks_dummy_persona_change_property_callback, _data_->_data19_, folks_dummy_full_persona_change_roles_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block19_data_unref (_data_->_data19_);
	_data_->_data19_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_is_favourite_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeIsFavouriteData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeIsFavouriteData, _data_);
}


static void folks_dummy_full_persona_real_change_is_favourite (FolksFavouriteDetails* base, gboolean is_favourite, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeIsFavouriteData* _data_;
	FolksDummyFullPersona* _tmp0_;
	gboolean _tmp1_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeIsFavouriteData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_is_favourite);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_is_favourite_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = is_favourite;
	_data_->is_favourite = _tmp1_;
	folks_dummy_full_persona_real_change_is_favourite_co (_data_);
}


static void folks_dummy_full_persona_real_change_is_favourite_finish (FolksFavouriteDetails* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeIsFavouriteData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block20Data* block20_data_ref (Block20Data* _data20_) {
	g_atomic_int_inc (&_data20_->_ref_count_);
	return _data20_;
}


static void block20_data_unref (void * _userdata_) {
	Block20Data* _data20_;
	_data20_ = (Block20Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data20_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data20_->self;
		_g_object_unref0 (self);
		g_slice_free (Block20Data, _data20_);
	}
}


static void __lambda25_ (Block20Data* _data20_) {
	FolksDummyFullPersona* self;
	gboolean _tmp0_;
	self = _data20_->self;
	_tmp0_ = _data20_->is_favourite;
	folks_dummy_full_persona_update_is_favourite (self, _tmp0_);
}


static void ___lambda25__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda25_ (self);
}


static void folks_dummy_full_persona_change_is_favourite_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeIsFavouriteData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_is_favourite_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_is_favourite_co (FolksDummyFullPersonaChangeIsFavouriteData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data20_ = g_slice_new0 (Block20Data);
	_data_->_data20_->_ref_count_ = 1;
	_data_->_data20_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->is_favourite;
	_data_->_data20_->is_favourite = _data_->_tmp0_;
	_data_->_data20_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "is-favourite", ___lambda25__folks_dummy_persona_change_property_callback, _data_->_data20_, folks_dummy_full_persona_change_is_favourite_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block20_data_unref (_data_->_data20_);
	_data_->_data20_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void folks_dummy_full_persona_real_change_anti_links_data_free (gpointer _data) {
	FolksDummyFullPersonaChangeAntiLinksData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (FolksDummyFullPersonaChangeAntiLinksData, _data_);
}


static void folks_dummy_full_persona_real_change_anti_links (FolksAntiLinkable* base, GeeSet* anti_links, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksDummyFullPersona * self;
	FolksDummyFullPersonaChangeAntiLinksData* _data_;
	FolksDummyFullPersona* _tmp0_;
	GeeSet* _tmp1_;
	GeeSet* _tmp2_;
	self = (FolksDummyFullPersona*) base;
	_data_ = g_slice_new0 (FolksDummyFullPersonaChangeAntiLinksData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, folks_dummy_full_persona_real_change_anti_links);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_dummy_full_persona_real_change_anti_links_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = anti_links;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (_data_->anti_links);
	_data_->anti_links = _tmp2_;
	folks_dummy_full_persona_real_change_anti_links_co (_data_);
}


static void folks_dummy_full_persona_real_change_anti_links_finish (FolksAntiLinkable* base, GAsyncResult* _res_, GError** error) {
	FolksDummyFullPersonaChangeAntiLinksData* _data_;
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
		return;
	}
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


/**
   * {@inheritDoc}
   *
   * @since 0.9.7
   */
static Block21Data* block21_data_ref (Block21Data* _data21_) {
	g_atomic_int_inc (&_data21_->_ref_count_);
	return _data21_;
}


static void block21_data_unref (void * _userdata_) {
	Block21Data* _data21_;
	_data21_ = (Block21Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data21_->_ref_count_)) {
		FolksDummyFullPersona* self;
		self = _data21_->self;
		_g_object_unref0 (_data21_->anti_links);
		_g_object_unref0 (self);
		g_slice_free (Block21Data, _data21_);
	}
}


static void __lambda26_ (Block21Data* _data21_) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = _data21_->self;
	_tmp0_ = _data21_->anti_links;
	folks_dummy_full_persona_update_anti_links (self, _tmp0_);
}


static void ___lambda26__folks_dummy_persona_change_property_callback (gpointer self) {
	__lambda26_ (self);
}


static void folks_dummy_full_persona_change_anti_links_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksDummyFullPersonaChangeAntiLinksData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	folks_dummy_full_persona_real_change_anti_links_co (_data_);
}


static gboolean folks_dummy_full_persona_real_change_anti_links_co (FolksDummyFullPersonaChangeAntiLinksData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data21_ = g_slice_new0 (Block21Data);
	_data_->_data21_->_ref_count_ = 1;
	_data_->_data21_->self = g_object_ref (_data_->self);
	_data_->_tmp0_ = _data_->anti_links;
	_g_object_unref0 (_data_->_data21_->anti_links);
	_data_->_data21_->anti_links = _data_->_tmp0_;
	_data_->_data21_->_async_data_ = _data_;
	_data_->_state_ = 1;
	folks_dummy_persona_change_property ((FolksDummyPersona*) _data_->self, "anti-links", ___lambda26__folks_dummy_persona_change_property_callback, _data_->_data21_, folks_dummy_full_persona_change_anti_links_ready, _data_);
	return FALSE;
	_state_1:
	folks_dummy_persona_change_property_finish ((FolksDummyPersona*) _data_->self, _data_->_res_);
	block21_data_unref (_data_->_data21_);
	_data_->_data21_ = NULL;
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static GeeHashSet* _folks_dummy_full_persona_dup_to_hash_set (FolksDummyFullPersona* self, GType t_type, GBoxedCopyFunc t_dup_func, GDestroyNotify t_destroy_func, GeeSet* input_set) {
	GeeHashSet* result = NULL;
	GeeHashSet* output_set;
	GeeHashSet* _tmp0_;
	GeeSet* _tmp1_;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (input_set != NULL, NULL);
	_tmp0_ = gee_hash_set_new (t_type, (GBoxedCopyFunc) t_dup_func, t_destroy_func, NULL, NULL, NULL, NULL, NULL, NULL);
	output_set = _tmp0_;
	_tmp1_ = input_set;
	gee_collection_add_all ((GeeCollection*) output_set, (GeeCollection*) _tmp1_);
	result = output_set;
	return result;
}


static GeeHashMultiMap* _folks_dummy_full_persona_dup_to_hash_multi_map (FolksDummyFullPersona* self, GType s_type, GBoxedCopyFunc s_dup_func, GDestroyNotify s_destroy_func, GType t_type, GBoxedCopyFunc t_dup_func, GDestroyNotify t_destroy_func, GeeMultiMap* input_multi_map) {
	GeeHashMultiMap* result = NULL;
	GeeHashMultiMap* output_multi_map;
	GeeHashMultiMap* _tmp0_;
	GeeMapIterator* iter;
	GeeMultiMap* _tmp1_;
	GeeMapIterator* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (input_multi_map != NULL, NULL);
	_tmp0_ = gee_hash_multi_map_new (s_type, (GBoxedCopyFunc) s_dup_func, s_destroy_func, t_type, (GBoxedCopyFunc) t_dup_func, t_destroy_func, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	output_multi_map = _tmp0_;
	_tmp1_ = input_multi_map;
	_tmp2_ = gee_multi_map_map_iterator (_tmp1_);
	iter = _tmp2_;
	while (TRUE) {
		GeeMapIterator* _tmp3_;
		gboolean _tmp4_;
		GeeHashMultiMap* _tmp5_;
		GeeMapIterator* _tmp6_;
		gpointer _tmp7_;
		gpointer _tmp8_;
		GeeMapIterator* _tmp9_;
		gpointer _tmp10_;
		gpointer _tmp11_;
		_tmp3_ = iter;
		_tmp4_ = gee_map_iterator_next (_tmp3_);
		if (!(_tmp4_ == TRUE)) {
			break;
		}
		_tmp5_ = output_multi_map;
		_tmp6_ = iter;
		_tmp7_ = gee_map_iterator_get_key (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = iter;
		_tmp10_ = gee_map_iterator_get_value (_tmp9_);
		_tmp11_ = _tmp10_;
		gee_multi_map_set ((GeeMultiMap*) _tmp5_, _tmp8_, _tmp11_);
		_t_destroy_func0 (_tmp11_);
		_s_destroy_func0 (_tmp8_);
	}
	result = output_multi_map;
	_g_object_unref0 (iter);
	return result;
}


/**
   * Update persona's gender.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.GenderDetails.gender} property. It is intended to be used for
   * testing code which consumes this property. If the property value changes,
   * this results in a property change notification on the persona.
   *
   * @param gender persona's new gender
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_gender (FolksDummyFullPersona* self, FolksGender gender) {
	FolksGender _tmp0_;
	FolksGender _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_gender;
	_tmp1_ = gender;
	if (_tmp0_ != _tmp1_) {
		FolksGender _tmp2_;
		_tmp2_ = gender;
		self->priv->_gender = _tmp2_;
		g_object_notify ((GObject*) self, "gender");
	}
}


/**
   * Update persona's birthday calendar event ID.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.BirthdayDetails.calendar_event_id} property. It is intended to
   * be used for testing code which consumes this property. If the property
   * value changes, this results in a property change notification on the
   * persona.
   *
   * @param calendar_event_id persona's new birthday calendar event ID
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_calendar_event_id (FolksDummyFullPersona* self, const gchar* calendar_event_id) {
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp0_ = calendar_event_id;
	_tmp1_ = self->priv->_calendar_event_id;
	if (g_strcmp0 (_tmp0_, _tmp1_) != 0) {
		const gchar* _tmp2_;
		gchar* _tmp3_;
		_tmp2_ = calendar_event_id;
		_tmp3_ = g_strdup (_tmp2_);
		_g_free0 (self->priv->_calendar_event_id);
		self->priv->_calendar_event_id = _tmp3_;
		g_object_notify ((GObject*) self, "calendar-event-id");
	}
}


/**
   * Update persona's birthday.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.BirthdayDetails.birthday} property. It is intended to be used
   * for testing code which consumes this property. If the property value
   * changes, this results in a property change notification on the persona.
   *
   * @param birthday persona's new birthday
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_birthday (FolksDummyFullPersona* self, GDateTime* birthday) {
	gboolean _tmp0_ = FALSE;
	GDateTime* _tmp1_;
	GDateTime* _tmp2_;
	g_return_if_fail (self != NULL);
	_tmp1_ = self->priv->_birthday;
	_tmp2_ = birthday;
	if ((_tmp1_ == NULL) != (_tmp2_ == NULL)) {
		_tmp0_ = TRUE;
	} else {
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
		GDateTime* _tmp5_;
		_tmp5_ = self->priv->_birthday;
		if (_tmp5_ != NULL) {
			GDateTime* _tmp6_;
			_tmp6_ = birthday;
			_tmp4_ = _tmp6_ != NULL;
		} else {
			_tmp4_ = FALSE;
		}
		if (_tmp4_) {
			GDateTime* _tmp7_;
			GDateTime* _tmp8_;
			gboolean _tmp9_;
			_tmp7_ = self->priv->_birthday;
			_tmp8_ = birthday;
			_tmp9_ = g_date_time_equal ((GDateTime*) _tmp7_, (GDateTime*) _tmp8_);
			_tmp3_ = !_tmp9_;
		} else {
			_tmp3_ = FALSE;
		}
		_tmp0_ = _tmp3_;
	}
	if (_tmp0_) {
		GDateTime* _tmp10_;
		GDateTime* _tmp11_;
		_tmp10_ = birthday;
		_tmp11_ = _g_date_time_ref0 (_tmp10_);
		_g_date_time_unref0 (self->priv->_birthday);
		self->priv->_birthday = _tmp11_;
		g_object_notify ((GObject*) self, "birthday");
	}
}


/**
   * Update persona's roles.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.RoleDetails.roles} property. It is intended to be used for
   * testing code which consumes this property. If the property value changes,
   * this results in a property change notification on the persona.
   *
   * @param roles persona's new roles
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_roles (FolksDummyFullPersona* self, GeeSet* roles) {
	GeeSet* _tmp0_;
	GeeHashSet* _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (roles != NULL);
	_tmp0_ = roles;
	_tmp1_ = self->priv->_roles;
	_tmp2_ = folks_internal_equal_sets (FOLKS_TYPE_ROLE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp0_, (GeeSet*) _tmp1_);
	if (!_tmp2_) {
		GeeSet* _tmp3_;
		GeeHashSet* _tmp4_;
		GeeHashSet* _tmp5_;
		GeeSet* _tmp6_;
		GeeSet* _tmp7_;
		_tmp3_ = roles;
		_tmp4_ = _folks_dummy_full_persona_dup_to_hash_set (self, FOLKS_TYPE_ROLE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp3_);
		_g_object_unref0 (self->priv->_roles);
		self->priv->_roles = _tmp4_;
		_tmp5_ = self->priv->_roles;
		_tmp6_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp5_);
		_tmp7_ = _tmp6_;
		_g_object_unref0 (self->priv->_roles_ro);
		self->priv->_roles_ro = _tmp7_;
		g_object_notify ((GObject*) self, "roles");
	}
}


/**
   * Update persona's groups.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.GroupDetails.groups} property. It is intended to be used for
   * testing code which consumes this property. If the property value changes,
   * this results in a property change notification on the persona.
   *
   * @param groups persona's new groups
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_groups (FolksDummyFullPersona* self, GeeSet* groups) {
	GeeSet* _tmp0_;
	GeeHashSet* _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (groups != NULL);
	_tmp0_ = groups;
	_tmp1_ = self->priv->_groups;
	_tmp2_ = folks_internal_equal_sets (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp0_, (GeeSet*) _tmp1_);
	if (!_tmp2_) {
		GeeSet* _tmp3_;
		GeeHashSet* _tmp4_;
		GeeHashSet* _tmp5_;
		GeeSet* _tmp6_;
		GeeSet* _tmp7_;
		_tmp3_ = groups;
		_tmp4_ = _folks_dummy_full_persona_dup_to_hash_set (self, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp3_);
		_g_object_unref0 (self->priv->_groups);
		self->priv->_groups = _tmp4_;
		_tmp5_ = self->priv->_groups;
		_tmp6_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp5_);
		_tmp7_ = _tmp6_;
		_g_object_unref0 (self->priv->_groups_ro);
		self->priv->_groups_ro = _tmp7_;
		g_object_notify ((GObject*) self, "groups");
	}
}


/**
   * Update persona's web service addresses.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.WebServiceDetails.web_service_addresses} property. It is
   * intended to be used for testing code which consumes this property. If the
   * property value changes, this results in a property change notification on
   * the persona.
   *
   * @param web_service_addresses persona's new web service addresses
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_web_service_addresses (FolksDummyFullPersona* self, GeeMultiMap* web_service_addresses) {
	GeeMultiMap* _tmp0_;
	GeeHashMultiMap* _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (web_service_addresses != NULL);
	_tmp0_ = web_service_addresses;
	_tmp1_ = self->priv->_web_service_addresses;
	_tmp2_ = folks_utils_multi_map_str_afd_equal (_tmp0_, (GeeMultiMap*) _tmp1_);
	if (!_tmp2_) {
		GeeMultiMap* _tmp3_;
		GeeHashMultiMap* _tmp4_;
		_tmp3_ = web_service_addresses;
		_tmp4_ = _folks_dummy_full_persona_dup_to_hash_multi_map (self, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_WEB_SERVICE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp3_);
		_g_object_unref0 (self->priv->_web_service_addresses);
		self->priv->_web_service_addresses = _tmp4_;
		g_object_notify ((GObject*) self, "web-service-addresses");
	}
}


/**
   * Update persona's e-mail addresses.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.EmailDetails.email_addresses} property. It is intended to be
   * used for testing code which consumes this property. If the property value
   * changes, this results in a property change notification on the persona.
   *
   * @param email_addresses persona's new e-mail addresses
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_email_addresses (FolksDummyFullPersona* self, GeeSet* email_addresses) {
	GeeSet* _tmp0_;
	GeeHashSet* _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (email_addresses != NULL);
	_tmp0_ = email_addresses;
	_tmp1_ = self->priv->_email_addresses;
	_tmp2_ = folks_internal_equal_sets (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp0_, (GeeSet*) _tmp1_);
	if (!_tmp2_) {
		GeeSet* _tmp3_;
		GeeHashSet* _tmp4_;
		GeeHashSet* _tmp5_;
		GeeSet* _tmp6_;
		GeeSet* _tmp7_;
		_tmp3_ = email_addresses;
		_tmp4_ = _folks_dummy_full_persona_dup_to_hash_set (self, FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp3_);
		_g_object_unref0 (self->priv->_email_addresses);
		self->priv->_email_addresses = _tmp4_;
		_tmp5_ = self->priv->_email_addresses;
		_tmp6_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp5_);
		_tmp7_ = _tmp6_;
		_g_object_unref0 (self->priv->_email_addresses_ro);
		self->priv->_email_addresses_ro = _tmp7_;
		g_object_notify ((GObject*) self, "email-addresses");
	}
}


/**
   * Update persona's notes.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.NoteDetails.notes} property. It is intended to be used for
   * testing code which consumes this property. If the property value changes,
   * this results in a property change notification on the persona.
   *
   * @param notes persona's new notes
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_notes (FolksDummyFullPersona* self, GeeSet* notes) {
	GeeSet* _tmp0_;
	GeeHashSet* _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (notes != NULL);
	_tmp0_ = notes;
	_tmp1_ = self->priv->_notes;
	_tmp2_ = folks_internal_equal_sets (FOLKS_TYPE_NOTE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp0_, (GeeSet*) _tmp1_);
	if (!_tmp2_) {
		GeeSet* _tmp3_;
		GeeHashSet* _tmp4_;
		GeeHashSet* _tmp5_;
		GeeSet* _tmp6_;
		GeeSet* _tmp7_;
		_tmp3_ = notes;
		_tmp4_ = _folks_dummy_full_persona_dup_to_hash_set (self, FOLKS_TYPE_NOTE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp3_);
		_g_object_unref0 (self->priv->_notes);
		self->priv->_notes = _tmp4_;
		_tmp5_ = self->priv->_notes;
		_tmp6_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp5_);
		_tmp7_ = _tmp6_;
		_g_object_unref0 (self->priv->_notes_ro);
		self->priv->_notes_ro = _tmp7_;
		g_object_notify ((GObject*) self, "notes");
	}
}


/**
   * Update persona's full name.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.NameDetails.full_name} property. It is intended to be used for
   * testing code which consumes this property. If the property value changes,
   * this results in a property change notification on the persona.
   *
   * @param full_name persona's new full name
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_full_name (FolksDummyFullPersona* self, const gchar* full_name) {
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (full_name != NULL);
	_tmp0_ = self->priv->_full_name;
	_tmp1_ = full_name;
	if (g_strcmp0 (_tmp0_, _tmp1_) != 0) {
		const gchar* _tmp2_;
		gchar* _tmp3_;
		_tmp2_ = full_name;
		_tmp3_ = g_strdup (_tmp2_);
		_g_free0 (self->priv->_full_name);
		self->priv->_full_name = _tmp3_;
		g_object_notify ((GObject*) self, "full-name");
	}
}


/**
   * Update persona's nickname.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.NameDetails.nickname} property. It is intended to be used for
   * testing code which consumes this property. If the property value changes,
   * this results in a property change notification on the persona.
   *
   * @param nickname persona's new nickname
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_nickname (FolksDummyFullPersona* self, const gchar* nickname) {
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (nickname != NULL);
	_tmp0_ = self->priv->_nickname;
	_tmp1_ = nickname;
	if (g_strcmp0 (_tmp0_, _tmp1_) != 0) {
		const gchar* _tmp2_;
		gchar* _tmp3_;
		_tmp2_ = nickname;
		_tmp3_ = g_strdup (_tmp2_);
		_g_free0 (self->priv->_nickname);
		self->priv->_nickname = _tmp3_;
		g_object_notify ((GObject*) self, "nickname");
	}
}


/**
   * Update persona's structured name.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.NameDetails.structured_name} property. It is intended to be
   * used for testing code which consumes this property. If the property value
   * changes, this results in a property change notification on the persona.
   *
   * @param structured_name persona's new structured name
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_structured_name (FolksDummyFullPersona* self, FolksStructuredName* structured_name) {
	gboolean _tmp0_ = FALSE;
	FolksStructuredName* _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp1_ = structured_name;
	if (_tmp1_ != NULL) {
		FolksStructuredName* _tmp2_;
		gboolean _tmp3_;
		_tmp2_ = structured_name;
		_tmp3_ = folks_structured_name_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, FOLKS_TYPE_STRUCTURED_NAME, FolksStructuredName));
		_tmp0_ = !_tmp3_;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		FolksStructuredName* _tmp4_;
		FolksStructuredName* _tmp5_;
		_tmp4_ = structured_name;
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, FOLKS_TYPE_STRUCTURED_NAME, FolksStructuredName));
		_g_object_unref0 (self->priv->_structured_name);
		self->priv->_structured_name = _tmp5_;
		g_object_notify ((GObject*) self, "structured-name");
	} else {
		FolksStructuredName* _tmp6_;
		_tmp6_ = self->priv->_structured_name;
		if (_tmp6_ != NULL) {
			_g_object_unref0 (self->priv->_structured_name);
			self->priv->_structured_name = NULL;
			g_object_notify ((GObject*) self, "structured-name");
		}
	}
}


/**
   * Update persona's avatar.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.AvatarDetails.avatar} property. It is intended to be used for
   * testing code which consumes this property. If the property value changes,
   * this results in a property change notification on the persona.
   *
   * @param avatar persona's new avatar
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_avatar (FolksDummyFullPersona* self, GLoadableIcon* avatar) {
	gboolean _tmp0_ = FALSE;
	GLoadableIcon* _tmp1_;
	GLoadableIcon* _tmp2_;
	g_return_if_fail (self != NULL);
	_tmp1_ = self->priv->_avatar;
	_tmp2_ = avatar;
	if ((_tmp1_ == NULL) != (_tmp2_ == NULL)) {
		_tmp0_ = TRUE;
	} else {
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
		GLoadableIcon* _tmp5_;
		_tmp5_ = self->priv->_avatar;
		if (_tmp5_ != NULL) {
			GLoadableIcon* _tmp6_;
			_tmp6_ = avatar;
			_tmp4_ = _tmp6_ != NULL;
		} else {
			_tmp4_ = FALSE;
		}
		if (_tmp4_) {
			GLoadableIcon* _tmp7_;
			GLoadableIcon* _tmp8_;
			gboolean _tmp9_;
			_tmp7_ = self->priv->_avatar;
			_tmp8_ = avatar;
			_tmp9_ = g_icon_equal ((GIcon*) G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, g_loadable_icon_get_type (), GLoadableIcon), (GIcon*) G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, g_loadable_icon_get_type (), GLoadableIcon));
			_tmp3_ = !_tmp9_;
		} else {
			_tmp3_ = FALSE;
		}
		_tmp0_ = _tmp3_;
	}
	if (_tmp0_) {
		GLoadableIcon* _tmp10_;
		GLoadableIcon* _tmp11_;
		_tmp10_ = avatar;
		_tmp11_ = _g_object_ref0 (_tmp10_);
		_g_object_unref0 (self->priv->_avatar);
		self->priv->_avatar = _tmp11_;
		g_object_notify ((GObject*) self, "avatar");
	}
}


/**
   * Update persona's URIs.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.UrlDetails.urls} property. It is intended to be used for
   * testing code which consumes this property. If the property value changes,
   * this results in a property change notification on the persona.
   *
   * @param urls persona's new URIs
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_urls (FolksDummyFullPersona* self, GeeSet* urls) {
	GeeSet* _tmp0_;
	GeeHashSet* _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (urls != NULL);
	_tmp0_ = urls;
	_tmp1_ = self->priv->_urls;
	_tmp2_ = folks_utils_set_afd_equal (_tmp0_, (GeeSet*) _tmp1_);
	if (!_tmp2_) {
		GeeSet* _tmp3_;
		GeeHashSet* _tmp4_;
		GeeHashSet* _tmp5_;
		GeeSet* _tmp6_;
		GeeSet* _tmp7_;
		_tmp3_ = urls;
		_tmp4_ = _folks_dummy_full_persona_dup_to_hash_set (self, FOLKS_TYPE_URL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp3_);
		_g_object_unref0 (self->priv->_urls);
		self->priv->_urls = _tmp4_;
		_tmp5_ = self->priv->_urls;
		_tmp6_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp5_);
		_tmp7_ = _tmp6_;
		_g_object_unref0 (self->priv->_urls_ro);
		self->priv->_urls_ro = _tmp7_;
		g_object_notify ((GObject*) self, "urls");
	}
}


/**
   * Update persona's IM addresses.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.ImDetails.im_addresses} property. It is intended to be used
   * for testing code which consumes this property. If the property value
   * changes, this results in a property change notification on the persona.
   *
   * @param im_addresses persona's new IM addresses
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_im_addresses (FolksDummyFullPersona* self, GeeMultiMap* im_addresses) {
	GeeMultiMap* _tmp0_;
	GeeHashMultiMap* _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (im_addresses != NULL);
	_tmp0_ = im_addresses;
	_tmp1_ = self->priv->_im_addresses;
	_tmp2_ = folks_utils_multi_map_str_afd_equal (_tmp0_, (GeeMultiMap*) _tmp1_);
	if (!_tmp2_) {
		GeeMultiMap* _tmp3_;
		GeeHashMultiMap* _tmp4_;
		_tmp3_ = im_addresses;
		_tmp4_ = _folks_dummy_full_persona_dup_to_hash_multi_map (self, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_IM_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp3_);
		_g_object_unref0 (self->priv->_im_addresses);
		self->priv->_im_addresses = _tmp4_;
		g_object_notify ((GObject*) self, "im-addresses");
	}
}


/**
   * Update persona's phone numbers.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.PhoneDetails.phone_numbers} property. It is intended to be
   * used for testing code which consumes this property. If the property value
   * changes, this results in a property change notification on the persona.
   *
   * @param phone_numbers persona's new phone numbers
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_phone_numbers (FolksDummyFullPersona* self, GeeSet* phone_numbers) {
	GeeSet* _tmp0_;
	GeeHashSet* _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (phone_numbers != NULL);
	_tmp0_ = phone_numbers;
	_tmp1_ = self->priv->_phone_numbers;
	_tmp2_ = folks_utils_set_string_afd_equal (_tmp0_, (GeeSet*) _tmp1_);
	if (!_tmp2_) {
		GeeSet* _tmp3_;
		GeeHashSet* _tmp4_;
		GeeHashSet* _tmp5_;
		GeeSet* _tmp6_;
		GeeSet* _tmp7_;
		_tmp3_ = phone_numbers;
		_tmp4_ = _folks_dummy_full_persona_dup_to_hash_set (self, FOLKS_TYPE_PHONE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp3_);
		_g_object_unref0 (self->priv->_phone_numbers);
		self->priv->_phone_numbers = _tmp4_;
		_tmp5_ = self->priv->_phone_numbers;
		_tmp6_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp5_);
		_tmp7_ = _tmp6_;
		_g_object_unref0 (self->priv->_phone_numbers_ro);
		self->priv->_phone_numbers_ro = _tmp7_;
		g_object_notify ((GObject*) self, "phone-numbers");
	}
}


/**
   * Update persona's postal addresses.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.PostalAddressDetails.postal_addresses} property. It is
   * intended to be used for testing code which consumes this property. If the
   * property value changes, this results in a property change notification on
   * the persona.
   *
   * @param postal_addresses persona's new postal addresses
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_postal_addresses (FolksDummyFullPersona* self, GeeSet* postal_addresses) {
	GeeSet* _tmp0_;
	GeeHashSet* _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (postal_addresses != NULL);
	_tmp0_ = postal_addresses;
	_tmp1_ = self->priv->_postal_addresses;
	_tmp2_ = folks_internal_equal_sets (FOLKS_TYPE_POSTAL_ADDRESS_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp0_, (GeeSet*) _tmp1_);
	if (!_tmp2_) {
		GeeSet* _tmp3_;
		GeeHashSet* _tmp4_;
		GeeHashSet* _tmp5_;
		GeeSet* _tmp6_;
		GeeSet* _tmp7_;
		_tmp3_ = postal_addresses;
		_tmp4_ = _folks_dummy_full_persona_dup_to_hash_set (self, FOLKS_TYPE_POSTAL_ADDRESS_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp3_);
		_g_object_unref0 (self->priv->_postal_addresses);
		self->priv->_postal_addresses = _tmp4_;
		_tmp5_ = self->priv->_postal_addresses;
		_tmp6_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp5_);
		_tmp7_ = _tmp6_;
		_g_object_unref0 (self->priv->_postal_addresses_ro);
		self->priv->_postal_addresses_ro = _tmp7_;
		g_object_notify ((GObject*) self, "postal-addresses");
	}
}


/**
   * Update persona's local IDs.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.LocalIdDetails.local_ids} property. It is intended to be used
   * for testing code which consumes this property. If the property value
   * changes, this results in a property change notification on the persona.
   *
   * @param local_ids persona's new local IDs
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_local_ids (FolksDummyFullPersona* self, GeeSet* local_ids) {
	GeeSet* _tmp0_;
	GeeSet* _tmp1_;
	GeeSet* _tmp2_;
	gboolean _tmp3_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (local_ids != NULL);
	_tmp0_ = local_ids;
	_tmp1_ = folks_local_id_details_get_local_ids ((FolksLocalIdDetails*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = folks_internal_equal_sets (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp0_, _tmp2_);
	if (!_tmp3_) {
		GeeSet* _tmp4_;
		GeeHashSet* _tmp5_;
		GeeHashSet* _tmp6_;
		GeeSet* _tmp7_;
		GeeSet* _tmp8_;
		_tmp4_ = local_ids;
		_tmp5_ = _folks_dummy_full_persona_dup_to_hash_set (self, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp4_);
		_g_object_unref0 (self->priv->_local_ids);
		self->priv->_local_ids = _tmp5_;
		_tmp6_ = self->priv->_local_ids;
		_tmp7_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp6_);
		_tmp8_ = _tmp7_;
		_g_object_unref0 (self->priv->_local_ids_ro);
		self->priv->_local_ids_ro = _tmp8_;
		g_object_notify ((GObject*) self, "local-ids");
	}
}


/**
   * Update persona's status as a favourite.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.FavouriteDetails.is_favourite} property. It is intended to be
   * used for testing code which consumes this property. If the property value
   * changes, this results in a property change notification on the persona.
   *
   * @param is_favourite persona's new status as a favourite
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_is_favourite (FolksDummyFullPersona* self, gboolean is_favourite) {
	gboolean _tmp0_;
	gboolean _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp0_ = is_favourite;
	_tmp1_ = self->priv->_is_favourite;
	if (_tmp0_ != _tmp1_) {
		gboolean _tmp2_;
		_tmp2_ = is_favourite;
		self->priv->_is_favourite = _tmp2_;
		g_object_notify ((GObject*) self, "is-favourite");
	}
}


/**
   * Update persona's anti-links.
   *
   * This simulates a backing-store-side update of the persona's
   * {@link Folks.AntiLinkable.anti_links} property. It is intended to be used
   * for testing code which consumes this property. If the property value
   * changes, this results in a property change notification on the persona.
   *
   * @param anti_links persona's new anti-links
   * @since 0.9.7
   */
void folks_dummy_full_persona_update_anti_links (FolksDummyFullPersona* self, GeeSet* anti_links) {
	GeeSet* _tmp0_;
	GeeHashSet* _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (anti_links != NULL);
	_tmp0_ = anti_links;
	_tmp1_ = self->priv->_anti_links;
	_tmp2_ = folks_internal_equal_sets (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp0_, (GeeSet*) _tmp1_);
	if (!_tmp2_) {
		GeeSet* _tmp3_;
		GeeHashSet* _tmp4_;
		GeeHashSet* _tmp5_;
		GeeSet* _tmp6_;
		GeeSet* _tmp7_;
		_tmp3_ = anti_links;
		_tmp4_ = _folks_dummy_full_persona_dup_to_hash_set (self, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp3_);
		_g_object_unref0 (self->priv->_anti_links);
		self->priv->_anti_links = _tmp4_;
		_tmp5_ = self->priv->_anti_links;
		_tmp6_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp5_);
		_tmp7_ = _tmp6_;
		_g_object_unref0 (self->priv->_anti_links_ro);
		self->priv->_anti_links_ro = _tmp7_;
		g_object_notify ((GObject*) self, "anti-links");
	}
}


static GeeMultiMap* folks_dummy_full_persona_real_get_web_service_addresses (FolksWebServiceDetails* base) {
	GeeMultiMap* result;
	FolksDummyFullPersona* self;
	GeeHashMultiMap* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_web_service_addresses;
	result = (GeeMultiMap*) _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_web_service_addresses (FolksWebServiceDetails* base, GeeMultiMap* value) {
	FolksDummyFullPersona* self;
	GeeMultiMap* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_web_service_details_change_web_service_addresses ((FolksWebServiceDetails*) self, _tmp0_, NULL, NULL);
}


static GeeSet* folks_dummy_full_persona_real_get_local_ids (FolksLocalIdDetails* base) {
	GeeSet* result;
	FolksDummyFullPersona* self;
	GeeHashSet* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gboolean _tmp3_;
	GeeSet* _tmp7_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_local_ids;
	_tmp1_ = folks_persona_get_iid ((FolksPersona*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp0_, _tmp2_);
	if (_tmp3_ == FALSE) {
		GeeHashSet* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		_tmp4_ = self->priv->_local_ids;
		_tmp5_ = folks_persona_get_iid ((FolksPersona*) self);
		_tmp6_ = _tmp5_;
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp4_, _tmp6_);
	}
	_tmp7_ = self->priv->_local_ids_ro;
	result = _tmp7_;
	return result;
}


static void folks_dummy_full_persona_real_set_local_ids (FolksLocalIdDetails* base, GeeSet* value) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_local_id_details_change_local_ids ((FolksLocalIdDetails*) self, _tmp0_, NULL, NULL);
}


static GeeSet* folks_dummy_full_persona_real_get_postal_addresses (FolksPostalAddressDetails* base) {
	GeeSet* result;
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_postal_addresses_ro;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_postal_addresses (FolksPostalAddressDetails* base, GeeSet* value) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_postal_address_details_change_postal_addresses ((FolksPostalAddressDetails*) self, _tmp0_, NULL, NULL);
}


static GeeSet* folks_dummy_full_persona_real_get_phone_numbers (FolksPhoneDetails* base) {
	GeeSet* result;
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_phone_numbers_ro;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_phone_numbers (FolksPhoneDetails* base, GeeSet* value) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_phone_details_change_phone_numbers ((FolksPhoneDetails*) self, _tmp0_, NULL, NULL);
}


static GeeSet* folks_dummy_full_persona_real_get_email_addresses (FolksEmailDetails* base) {
	GeeSet* result;
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_email_addresses_ro;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_email_addresses (FolksEmailDetails* base, GeeSet* value) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_email_details_change_email_addresses ((FolksEmailDetails*) self, _tmp0_, NULL, NULL);
}


static GeeSet* folks_dummy_full_persona_real_get_notes (FolksNoteDetails* base) {
	GeeSet* result;
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_notes_ro;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_notes (FolksNoteDetails* base, GeeSet* value) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_note_details_change_notes ((FolksNoteDetails*) self, _tmp0_, NULL, NULL);
}


static GLoadableIcon* folks_dummy_full_persona_real_get_avatar (FolksAvatarDetails* base) {
	GLoadableIcon* result;
	FolksDummyFullPersona* self;
	GLoadableIcon* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_avatar;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_avatar (FolksAvatarDetails* base, GLoadableIcon* value) {
	FolksDummyFullPersona* self;
	GLoadableIcon* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_avatar_details_change_avatar ((FolksAvatarDetails*) self, _tmp0_, NULL, NULL);
}


static FolksStructuredName* folks_dummy_full_persona_real_get_structured_name (FolksNameDetails* base) {
	FolksStructuredName* result;
	FolksDummyFullPersona* self;
	FolksStructuredName* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_structured_name;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_structured_name (FolksNameDetails* base, FolksStructuredName* value) {
	FolksDummyFullPersona* self;
	FolksStructuredName* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_name_details_change_structured_name ((FolksNameDetails*) self, _tmp0_, NULL, NULL);
}


static const gchar* folks_dummy_full_persona_real_get_full_name (FolksNameDetails* base) {
	const gchar* result;
	FolksDummyFullPersona* self;
	const gchar* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_full_name;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_full_name (FolksNameDetails* base, const gchar* value) {
	FolksDummyFullPersona* self;
	const gchar* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_name_details_change_full_name ((FolksNameDetails*) self, _tmp0_, NULL, NULL);
}


static const gchar* folks_dummy_full_persona_real_get_nickname (FolksNameDetails* base) {
	const gchar* result;
	FolksDummyFullPersona* self;
	const gchar* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_nickname;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_nickname (FolksNameDetails* base, const gchar* value) {
	FolksDummyFullPersona* self;
	const gchar* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_name_details_change_nickname ((FolksNameDetails*) self, _tmp0_, NULL, NULL);
}


static FolksGender folks_dummy_full_persona_real_get_gender (FolksGenderDetails* base) {
	FolksGender result;
	FolksDummyFullPersona* self;
	FolksGender _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_gender;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_gender (FolksGenderDetails* base, FolksGender value) {
	FolksDummyFullPersona* self;
	FolksGender _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_gender_details_change_gender ((FolksGenderDetails*) self, _tmp0_, NULL, NULL);
}


static GeeSet* folks_dummy_full_persona_real_get_urls (FolksUrlDetails* base) {
	GeeSet* result;
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_urls_ro;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_urls (FolksUrlDetails* base, GeeSet* value) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_url_details_change_urls ((FolksUrlDetails*) self, _tmp0_, NULL, NULL);
}


static GeeMultiMap* folks_dummy_full_persona_real_get_im_addresses (FolksImDetails* base) {
	GeeMultiMap* result;
	FolksDummyFullPersona* self;
	GeeHashMultiMap* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_im_addresses;
	result = (GeeMultiMap*) _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_im_addresses (FolksImDetails* base, GeeMultiMap* value) {
	FolksDummyFullPersona* self;
	GeeMultiMap* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_im_details_change_im_addresses ((FolksImDetails*) self, _tmp0_, NULL, NULL);
}


static GeeSet* folks_dummy_full_persona_real_get_groups (FolksGroupDetails* base) {
	GeeSet* result;
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_groups_ro;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_groups (FolksGroupDetails* base, GeeSet* value) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_group_details_change_groups ((FolksGroupDetails*) self, _tmp0_, NULL, NULL);
}


static const gchar* folks_dummy_full_persona_real_get_calendar_event_id (FolksBirthdayDetails* base) {
	const gchar* result;
	FolksDummyFullPersona* self;
	const gchar* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_calendar_event_id;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_calendar_event_id (FolksBirthdayDetails* base, const gchar* value) {
	FolksDummyFullPersona* self;
	const gchar* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_birthday_details_change_calendar_event_id ((FolksBirthdayDetails*) self, _tmp0_, NULL, NULL);
}


static GDateTime* folks_dummy_full_persona_real_get_birthday (FolksBirthdayDetails* base) {
	GDateTime* result;
	FolksDummyFullPersona* self;
	GDateTime* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_birthday;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_birthday (FolksBirthdayDetails* base, GDateTime* value) {
	FolksDummyFullPersona* self;
	GDateTime* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_birthday_details_change_birthday ((FolksBirthdayDetails*) self, _tmp0_, NULL, NULL);
}


static GeeSet* folks_dummy_full_persona_real_get_roles (FolksRoleDetails* base) {
	GeeSet* result;
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_roles_ro;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_roles (FolksRoleDetails* base, GeeSet* value) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_role_details_change_roles ((FolksRoleDetails*) self, _tmp0_, NULL, NULL);
}


static gboolean folks_dummy_full_persona_real_get_is_favourite (FolksFavouriteDetails* base) {
	gboolean result;
	FolksDummyFullPersona* self;
	gboolean _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_is_favourite;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_is_favourite (FolksFavouriteDetails* base, gboolean value) {
	FolksDummyFullPersona* self;
	gboolean _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_favourite_details_change_is_favourite ((FolksFavouriteDetails*) self, _tmp0_, NULL, NULL);
}


static GeeSet* folks_dummy_full_persona_real_get_anti_links (FolksAntiLinkable* base) {
	GeeSet* result;
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = self->priv->_anti_links_ro;
	result = _tmp0_;
	return result;
}


static void folks_dummy_full_persona_real_set_anti_links (FolksAntiLinkable* base, GeeSet* value) {
	FolksDummyFullPersona* self;
	GeeSet* _tmp0_;
	self = (FolksDummyFullPersona*) base;
	_tmp0_ = value;
	folks_anti_linkable_change_anti_links ((FolksAntiLinkable*) self, _tmp0_, NULL, NULL);
}


static GObject * folks_dummy_full_persona_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	FolksDummyFullPersona * self;
	GeeHashSet* _tmp0_;
	GeeSet* _tmp1_;
	GeeSet* _tmp2_;
	GeeHashSet* _tmp3_;
	GeeSet* _tmp4_;
	GeeSet* _tmp5_;
	GeeHashSet* _tmp6_;
	GeeSet* _tmp7_;
	GeeSet* _tmp8_;
	GeeHashSet* _tmp9_;
	GeeSet* _tmp10_;
	GeeSet* _tmp11_;
	GeeHashSet* _tmp12_;
	GeeSet* _tmp13_;
	GeeSet* _tmp14_;
	GeeHashSet* _tmp15_;
	GeeSet* _tmp16_;
	GeeSet* _tmp17_;
	GeeHashSet* _tmp18_;
	GeeSet* _tmp19_;
	GeeSet* _tmp20_;
	GeeHashSet* _tmp21_;
	GeeSet* _tmp22_;
	GeeSet* _tmp23_;
	GeeHashSet* _tmp24_;
	GeeSet* _tmp25_;
	GeeSet* _tmp26_;
	parent_class = G_OBJECT_CLASS (folks_dummy_full_persona_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, FOLKS_DUMMY_TYPE_FULL_PERSONA, FolksDummyFullPersona);
	_tmp0_ = self->priv->_local_ids;
	_tmp1_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp0_);
	_tmp2_ = _tmp1_;
	_g_object_unref0 (self->priv->_local_ids_ro);
	self->priv->_local_ids_ro = _tmp2_;
	_tmp3_ = self->priv->_postal_addresses;
	_tmp4_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp3_);
	_tmp5_ = _tmp4_;
	_g_object_unref0 (self->priv->_postal_addresses_ro);
	self->priv->_postal_addresses_ro = _tmp5_;
	_tmp6_ = self->priv->_email_addresses;
	_tmp7_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp6_);
	_tmp8_ = _tmp7_;
	_g_object_unref0 (self->priv->_email_addresses_ro);
	self->priv->_email_addresses_ro = _tmp8_;
	_tmp9_ = self->priv->_phone_numbers;
	_tmp10_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp9_);
	_tmp11_ = _tmp10_;
	_g_object_unref0 (self->priv->_phone_numbers_ro);
	self->priv->_phone_numbers_ro = _tmp11_;
	_tmp12_ = self->priv->_notes;
	_tmp13_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp12_);
	_tmp14_ = _tmp13_;
	_g_object_unref0 (self->priv->_notes_ro);
	self->priv->_notes_ro = _tmp14_;
	_tmp15_ = self->priv->_urls;
	_tmp16_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp15_);
	_tmp17_ = _tmp16_;
	_g_object_unref0 (self->priv->_urls_ro);
	self->priv->_urls_ro = _tmp17_;
	_tmp18_ = self->priv->_groups;
	_tmp19_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp18_);
	_tmp20_ = _tmp19_;
	_g_object_unref0 (self->priv->_groups_ro);
	self->priv->_groups_ro = _tmp20_;
	_tmp21_ = self->priv->_roles;
	_tmp22_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp21_);
	_tmp23_ = _tmp22_;
	_g_object_unref0 (self->priv->_roles_ro);
	self->priv->_roles_ro = _tmp23_;
	_tmp24_ = self->priv->_anti_links;
	_tmp25_ = gee_abstract_set_get_read_only_view ((GeeAbstractSet*) _tmp24_);
	_tmp26_ = _tmp25_;
	_g_object_unref0 (self->priv->_anti_links_ro);
	self->priv->_anti_links_ro = _tmp26_;
	folks_dummy_persona_update_linkable_properties ((FolksDummyPersona*) self, FOLKS_DUMMY_FULL_PERSONA__default_linkable_properties, G_N_ELEMENTS (FOLKS_DUMMY_FULL_PERSONA__default_linkable_properties));
	return obj;
}


static void folks_dummy_full_persona_class_init (FolksDummyFullPersonaClass * klass) {
	folks_dummy_full_persona_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (FolksDummyFullPersonaPrivate));
	G_OBJECT_CLASS (klass)->get_property = _vala_folks_dummy_full_persona_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_folks_dummy_full_persona_set_property;
	G_OBJECT_CLASS (klass)->constructor = folks_dummy_full_persona_constructor;
	G_OBJECT_CLASS (klass)->finalize = folks_dummy_full_persona_finalize;
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_WEB_SERVICE_ADDRESSES, g_param_spec_object ("web-service-addresses", "web-service-addresses", "web-service-addresses", GEE_TYPE_MULTI_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_LOCAL_IDS, g_param_spec_object ("local-ids", "local-ids", "local-ids", GEE_TYPE_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_POSTAL_ADDRESSES, g_param_spec_object ("postal-addresses", "postal-addresses", "postal-addresses", GEE_TYPE_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_PHONE_NUMBERS, g_param_spec_object ("phone-numbers", "phone-numbers", "phone-numbers", GEE_TYPE_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_EMAIL_ADDRESSES, g_param_spec_object ("email-addresses", "email-addresses", "email-addresses", GEE_TYPE_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_NOTES, g_param_spec_object ("notes", "notes", "notes", GEE_TYPE_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_AVATAR, g_param_spec_object ("avatar", "avatar", "avatar", g_loadable_icon_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_STRUCTURED_NAME, g_param_spec_object ("structured-name", "structured-name", "structured-name", FOLKS_TYPE_STRUCTURED_NAME, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_FULL_NAME, g_param_spec_string ("full-name", "full-name", "full-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_NICKNAME, g_param_spec_string ("nickname", "nickname", "nickname", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_GENDER, g_param_spec_enum ("gender", "gender", "gender", FOLKS_TYPE_GENDER, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_URLS, g_param_spec_object ("urls", "urls", "urls", GEE_TYPE_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_IM_ADDRESSES, g_param_spec_object ("im-addresses", "im-addresses", "im-addresses", GEE_TYPE_MULTI_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_GROUPS, g_param_spec_object ("groups", "groups", "groups", GEE_TYPE_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_CALENDAR_EVENT_ID, g_param_spec_string ("calendar-event-id", "calendar-event-id", "calendar-event-id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_BIRTHDAY, g_param_spec_boxed ("birthday", "birthday", "birthday", G_TYPE_DATE_TIME, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_ROLES, g_param_spec_object ("roles", "roles", "roles", GEE_TYPE_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * Whether this contact is a user-defined favourite.
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_IS_FAVOURITE, g_param_spec_boolean ("is-favourite", "is-favourite", "is-favourite", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * {@inheritDoc}
	   *
	   * @since 0.9.7
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_DUMMY_FULL_PERSONA_ANTI_LINKS, g_param_spec_object ("anti-links", "anti-links", "anti-links", GEE_TYPE_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void folks_dummy_full_persona_folks_anti_linkable_interface_init (FolksAntiLinkableIface * iface) {
	folks_dummy_full_persona_folks_anti_linkable_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_anti_links = (void (*) (FolksAntiLinkable *, GeeSet*, GError**)) folks_dummy_full_persona_real_change_anti_links;
	iface->change_anti_links_finish = folks_dummy_full_persona_real_change_anti_links_finish;
	iface->get_anti_links = folks_dummy_full_persona_real_get_anti_links;
	iface->set_anti_links = folks_dummy_full_persona_real_set_anti_links;
}


static void folks_dummy_full_persona_folks_avatar_details_interface_init (FolksAvatarDetailsIface * iface) {
	folks_dummy_full_persona_folks_avatar_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_avatar = (void (*) (FolksAvatarDetails *, GLoadableIcon*, GError**)) folks_dummy_full_persona_real_change_avatar;
	iface->change_avatar_finish = folks_dummy_full_persona_real_change_avatar_finish;
	iface->get_avatar = folks_dummy_full_persona_real_get_avatar;
	iface->set_avatar = folks_dummy_full_persona_real_set_avatar;
}


static void folks_dummy_full_persona_folks_birthday_details_interface_init (FolksBirthdayDetailsIface * iface) {
	folks_dummy_full_persona_folks_birthday_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_calendar_event_id = (void (*) (FolksBirthdayDetails *, const gchar*, GError**)) folks_dummy_full_persona_real_change_calendar_event_id;
	iface->change_calendar_event_id_finish = folks_dummy_full_persona_real_change_calendar_event_id_finish;
	iface->change_birthday = (void (*) (FolksBirthdayDetails *, GDateTime*, GError**)) folks_dummy_full_persona_real_change_birthday;
	iface->change_birthday_finish = folks_dummy_full_persona_real_change_birthday_finish;
	iface->get_calendar_event_id = folks_dummy_full_persona_real_get_calendar_event_id;
	iface->set_calendar_event_id = folks_dummy_full_persona_real_set_calendar_event_id;
	iface->get_birthday = folks_dummy_full_persona_real_get_birthday;
	iface->set_birthday = folks_dummy_full_persona_real_set_birthday;
}


static void folks_dummy_full_persona_folks_email_details_interface_init (FolksEmailDetailsIface * iface) {
	folks_dummy_full_persona_folks_email_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_email_addresses = (void (*) (FolksEmailDetails *, GeeSet*, GError**)) folks_dummy_full_persona_real_change_email_addresses;
	iface->change_email_addresses_finish = folks_dummy_full_persona_real_change_email_addresses_finish;
	iface->get_email_addresses = folks_dummy_full_persona_real_get_email_addresses;
	iface->set_email_addresses = folks_dummy_full_persona_real_set_email_addresses;
}


static void folks_dummy_full_persona_folks_favourite_details_interface_init (FolksFavouriteDetailsIface * iface) {
	folks_dummy_full_persona_folks_favourite_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_is_favourite = (void (*) (FolksFavouriteDetails *, gboolean, GError**)) folks_dummy_full_persona_real_change_is_favourite;
	iface->change_is_favourite_finish = folks_dummy_full_persona_real_change_is_favourite_finish;
	iface->get_is_favourite = folks_dummy_full_persona_real_get_is_favourite;
	iface->set_is_favourite = folks_dummy_full_persona_real_set_is_favourite;
}


static void folks_dummy_full_persona_folks_gender_details_interface_init (FolksGenderDetailsIface * iface) {
	folks_dummy_full_persona_folks_gender_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_gender = (void (*) (FolksGenderDetails *, FolksGender, GError**)) folks_dummy_full_persona_real_change_gender;
	iface->change_gender_finish = folks_dummy_full_persona_real_change_gender_finish;
	iface->get_gender = folks_dummy_full_persona_real_get_gender;
	iface->set_gender = folks_dummy_full_persona_real_set_gender;
}


static void folks_dummy_full_persona_folks_group_details_interface_init (FolksGroupDetailsIface * iface) {
	folks_dummy_full_persona_folks_group_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_group = (void (*) (FolksGroupDetails *, const gchar*, gboolean, GError**)) folks_dummy_full_persona_real_change_group;
	iface->change_group_finish = folks_dummy_full_persona_real_change_group_finish;
	iface->change_groups = (void (*) (FolksGroupDetails *, GeeSet*, GError**)) folks_dummy_full_persona_real_change_groups;
	iface->change_groups_finish = folks_dummy_full_persona_real_change_groups_finish;
	iface->get_groups = folks_dummy_full_persona_real_get_groups;
	iface->set_groups = folks_dummy_full_persona_real_set_groups;
}


static void folks_dummy_full_persona_folks_im_details_interface_init (FolksImDetailsIface * iface) {
	folks_dummy_full_persona_folks_im_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_im_addresses = (void (*) (FolksImDetails *, GeeMultiMap*, GError**)) folks_dummy_full_persona_real_change_im_addresses;
	iface->change_im_addresses_finish = folks_dummy_full_persona_real_change_im_addresses_finish;
	iface->get_im_addresses = folks_dummy_full_persona_real_get_im_addresses;
	iface->set_im_addresses = folks_dummy_full_persona_real_set_im_addresses;
}


static void folks_dummy_full_persona_folks_local_id_details_interface_init (FolksLocalIdDetailsIface * iface) {
	folks_dummy_full_persona_folks_local_id_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_local_ids = (void (*) (FolksLocalIdDetails *, GeeSet*, GError**)) folks_dummy_full_persona_real_change_local_ids;
	iface->change_local_ids_finish = folks_dummy_full_persona_real_change_local_ids_finish;
	iface->get_local_ids = folks_dummy_full_persona_real_get_local_ids;
	iface->set_local_ids = folks_dummy_full_persona_real_set_local_ids;
}


static void folks_dummy_full_persona_folks_name_details_interface_init (FolksNameDetailsIface * iface) {
	folks_dummy_full_persona_folks_name_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_structured_name = (void (*) (FolksNameDetails *, FolksStructuredName*, GError**)) folks_dummy_full_persona_real_change_structured_name;
	iface->change_structured_name_finish = folks_dummy_full_persona_real_change_structured_name_finish;
	iface->change_full_name = (void (*) (FolksNameDetails *, const gchar*, GError**)) folks_dummy_full_persona_real_change_full_name;
	iface->change_full_name_finish = folks_dummy_full_persona_real_change_full_name_finish;
	iface->change_nickname = (void (*) (FolksNameDetails *, const gchar*, GError**)) folks_dummy_full_persona_real_change_nickname;
	iface->change_nickname_finish = folks_dummy_full_persona_real_change_nickname_finish;
	iface->get_structured_name = folks_dummy_full_persona_real_get_structured_name;
	iface->set_structured_name = folks_dummy_full_persona_real_set_structured_name;
	iface->get_full_name = folks_dummy_full_persona_real_get_full_name;
	iface->set_full_name = folks_dummy_full_persona_real_set_full_name;
	iface->get_nickname = folks_dummy_full_persona_real_get_nickname;
	iface->set_nickname = folks_dummy_full_persona_real_set_nickname;
}


static void folks_dummy_full_persona_folks_note_details_interface_init (FolksNoteDetailsIface * iface) {
	folks_dummy_full_persona_folks_note_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_notes = (void (*) (FolksNoteDetails *, GeeSet*, GError**)) folks_dummy_full_persona_real_change_notes;
	iface->change_notes_finish = folks_dummy_full_persona_real_change_notes_finish;
	iface->get_notes = folks_dummy_full_persona_real_get_notes;
	iface->set_notes = folks_dummy_full_persona_real_set_notes;
}


static void folks_dummy_full_persona_folks_phone_details_interface_init (FolksPhoneDetailsIface * iface) {
	folks_dummy_full_persona_folks_phone_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_phone_numbers = (void (*) (FolksPhoneDetails *, GeeSet*, GError**)) folks_dummy_full_persona_real_change_phone_numbers;
	iface->change_phone_numbers_finish = folks_dummy_full_persona_real_change_phone_numbers_finish;
	iface->get_phone_numbers = folks_dummy_full_persona_real_get_phone_numbers;
	iface->set_phone_numbers = folks_dummy_full_persona_real_set_phone_numbers;
}


static void folks_dummy_full_persona_folks_role_details_interface_init (FolksRoleDetailsIface * iface) {
	folks_dummy_full_persona_folks_role_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_roles = (void (*) (FolksRoleDetails *, GeeSet*, GError**)) folks_dummy_full_persona_real_change_roles;
	iface->change_roles_finish = folks_dummy_full_persona_real_change_roles_finish;
	iface->get_roles = folks_dummy_full_persona_real_get_roles;
	iface->set_roles = folks_dummy_full_persona_real_set_roles;
}


static void folks_dummy_full_persona_folks_url_details_interface_init (FolksUrlDetailsIface * iface) {
	folks_dummy_full_persona_folks_url_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_urls = (void (*) (FolksUrlDetails *, GeeSet*, GError**)) folks_dummy_full_persona_real_change_urls;
	iface->change_urls_finish = folks_dummy_full_persona_real_change_urls_finish;
	iface->get_urls = folks_dummy_full_persona_real_get_urls;
	iface->set_urls = folks_dummy_full_persona_real_set_urls;
}


static void folks_dummy_full_persona_folks_postal_address_details_interface_init (FolksPostalAddressDetailsIface * iface) {
	folks_dummy_full_persona_folks_postal_address_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_postal_addresses = (void (*) (FolksPostalAddressDetails *, GeeSet*, GError**)) folks_dummy_full_persona_real_change_postal_addresses;
	iface->change_postal_addresses_finish = folks_dummy_full_persona_real_change_postal_addresses_finish;
	iface->get_postal_addresses = folks_dummy_full_persona_real_get_postal_addresses;
	iface->set_postal_addresses = folks_dummy_full_persona_real_set_postal_addresses;
}


static void folks_dummy_full_persona_folks_web_service_details_interface_init (FolksWebServiceDetailsIface * iface) {
	folks_dummy_full_persona_folks_web_service_details_parent_iface = g_type_interface_peek_parent (iface);
	iface->change_web_service_addresses = (void (*) (FolksWebServiceDetails *, GeeMultiMap*, GError**)) folks_dummy_full_persona_real_change_web_service_addresses;
	iface->change_web_service_addresses_finish = folks_dummy_full_persona_real_change_web_service_addresses_finish;
	iface->get_web_service_addresses = folks_dummy_full_persona_real_get_web_service_addresses;
	iface->set_web_service_addresses = folks_dummy_full_persona_real_set_web_service_addresses;
}


static void folks_dummy_full_persona_instance_init (FolksDummyFullPersona * self) {
	GeeHashMultiMap* _tmp0_;
	GeeHashSet* _tmp1_;
	GeeHashSet* _tmp2_;
	GeeHashSet* _tmp3_;
	GeeHashSet* _tmp4_;
	GeeHashSet* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	GeeHashSet* _tmp8_;
	GeeHashMultiMap* _tmp9_;
	GeeHashSet* _tmp10_;
	GeeHashSet* _tmp11_;
	GeeHashSet* _tmp12_;
	self->priv = FOLKS_DUMMY_FULL_PERSONA_GET_PRIVATE (self);
	_tmp0_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_WEB_SERVICE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
	self->priv->_web_service_addresses = _tmp0_;
	_tmp1_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->_local_ids = _tmp1_;
	_tmp2_ = gee_hash_set_new (FOLKS_TYPE_POSTAL_ADDRESS_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->_postal_addresses = _tmp2_;
	_tmp3_ = gee_hash_set_new (FOLKS_TYPE_PHONE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->_phone_numbers = _tmp3_;
	_tmp4_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
	self->priv->_email_addresses = _tmp4_;
	_tmp5_ = gee_hash_set_new (FOLKS_TYPE_NOTE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->_notes = _tmp5_;
	self->priv->_avatar = NULL;
	self->priv->_structured_name = NULL;
	_tmp6_ = g_strdup ("");
	self->priv->_full_name = _tmp6_;
	_tmp7_ = g_strdup ("");
	self->priv->_nickname = _tmp7_;
	self->priv->_gender = FOLKS_GENDER_UNSPECIFIED;
	_tmp8_ = gee_hash_set_new (FOLKS_TYPE_URL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->_urls = _tmp8_;
	_tmp9_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_IM_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
	self->priv->_im_addresses = _tmp9_;
	_tmp10_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->_groups = _tmp10_;
	self->priv->_calendar_event_id = NULL;
	self->priv->_birthday = NULL;
	_tmp11_ = gee_hash_set_new (FOLKS_TYPE_ROLE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->_roles = _tmp11_;
	self->priv->_is_favourite = FALSE;
	_tmp12_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->_anti_links = _tmp12_;
}


static void folks_dummy_full_persona_finalize (GObject * obj) {
	FolksDummyFullPersona * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, FOLKS_DUMMY_TYPE_FULL_PERSONA, FolksDummyFullPersona);
	_g_object_unref0 (self->priv->_web_service_addresses);
	_g_object_unref0 (self->priv->_local_ids);
	_g_object_unref0 (self->priv->_local_ids_ro);
	_g_object_unref0 (self->priv->_postal_addresses);
	_g_object_unref0 (self->priv->_postal_addresses_ro);
	_g_object_unref0 (self->priv->_phone_numbers);
	_g_object_unref0 (self->priv->_phone_numbers_ro);
	_g_object_unref0 (self->priv->_email_addresses);
	_g_object_unref0 (self->priv->_email_addresses_ro);
	_g_object_unref0 (self->priv->_notes);
	_g_object_unref0 (self->priv->_notes_ro);
	_g_object_unref0 (self->priv->_avatar);
	_g_object_unref0 (self->priv->_structured_name);
	_g_free0 (self->priv->_full_name);
	_g_free0 (self->priv->_nickname);
	_g_object_unref0 (self->priv->_urls);
	_g_object_unref0 (self->priv->_urls_ro);
	_g_object_unref0 (self->priv->_im_addresses);
	_g_object_unref0 (self->priv->_groups);
	_g_object_unref0 (self->priv->_groups_ro);
	_g_free0 (self->priv->_calendar_event_id);
	_g_date_time_unref0 (self->priv->_birthday);
	_g_object_unref0 (self->priv->_roles);
	_g_object_unref0 (self->priv->_roles_ro);
	_g_object_unref0 (self->priv->_anti_links);
	_g_object_unref0 (self->priv->_anti_links_ro);
	G_OBJECT_CLASS (folks_dummy_full_persona_parent_class)->finalize (obj);
}


/**
 * A persona subclass representing a single ‘full’ contact.
 *
 * This mocks up a ‘full’ persona which implements all the available property
 * interfaces provided by libfolks. This is in contrast with
 * {@link FolksDummy.Persona}, which provides a base class implementing none of
 * libfolks’ interfaces.
 *
 * The full dummy persona can be used to simulate a persona from most libfolks
 * backends, if writing a custom {@link FolksDummy.Persona} subclass is not an
 * option.
 *
 * There are two sides to this class’ interface: the normal methods required by
 * the libfolks ‘details’ interfaces, such as
 * {@link Folks.GenderDetails.change_gender},
 * and the backend methods which should be called by test driver code to
 * simulate changes in the backing store providing this persona, such as
 * {@link FullPersona.update_gender}. For example, test driver code should call
 * {@link FullPersona.update_nickname} to simulate the user editing a contact’s
 * nickname in an online address book which is being exposed to libfolks. The
 * ``update_``, ``register_`` and ``unregister_`` prefixes are commonly used for
 * backend methods.
 *
 * The API in {@link FolksDummy} is unstable and may change wildly. It is
 * designed mostly for use by libfolks unit tests.
 *
 * @since 0.9.7
 */
GType folks_dummy_full_persona_get_type (void) {
	static volatile gsize folks_dummy_full_persona_type_id__volatile = 0;
	if (g_once_init_enter (&folks_dummy_full_persona_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FolksDummyFullPersonaClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) folks_dummy_full_persona_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FolksDummyFullPersona), 0, (GInstanceInitFunc) folks_dummy_full_persona_instance_init, NULL };
		static const GInterfaceInfo folks_anti_linkable_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_anti_linkable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_avatar_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_avatar_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_birthday_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_birthday_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_email_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_email_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_favourite_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_favourite_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_gender_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_gender_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_group_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_group_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_im_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_im_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_local_id_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_local_id_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_name_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_name_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_note_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_note_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_phone_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_phone_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_role_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_role_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_url_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_url_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_postal_address_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_postal_address_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo folks_web_service_details_info = { (GInterfaceInitFunc) folks_dummy_full_persona_folks_web_service_details_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType folks_dummy_full_persona_type_id;
		folks_dummy_full_persona_type_id = g_type_register_static (FOLKS_DUMMY_TYPE_PERSONA, "FolksDummyFullPersona", &g_define_type_info, 0);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_ANTI_LINKABLE, &folks_anti_linkable_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_AVATAR_DETAILS, &folks_avatar_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_BIRTHDAY_DETAILS, &folks_birthday_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_EMAIL_DETAILS, &folks_email_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_FAVOURITE_DETAILS, &folks_favourite_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_GENDER_DETAILS, &folks_gender_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_GROUP_DETAILS, &folks_group_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_IM_DETAILS, &folks_im_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_LOCAL_ID_DETAILS, &folks_local_id_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_NAME_DETAILS, &folks_name_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_NOTE_DETAILS, &folks_note_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_PHONE_DETAILS, &folks_phone_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_ROLE_DETAILS, &folks_role_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_URL_DETAILS, &folks_url_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_POSTAL_ADDRESS_DETAILS, &folks_postal_address_details_info);
		g_type_add_interface_static (folks_dummy_full_persona_type_id, FOLKS_TYPE_WEB_SERVICE_DETAILS, &folks_web_service_details_info);
		g_once_init_leave (&folks_dummy_full_persona_type_id__volatile, folks_dummy_full_persona_type_id);
	}
	return folks_dummy_full_persona_type_id__volatile;
}


static void _vala_folks_dummy_full_persona_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	FolksDummyFullPersona * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, FOLKS_DUMMY_TYPE_FULL_PERSONA, FolksDummyFullPersona);
	switch (property_id) {
		case FOLKS_DUMMY_FULL_PERSONA_WEB_SERVICE_ADDRESSES:
		g_value_set_object (value, folks_web_service_details_get_web_service_addresses ((FolksWebServiceDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_LOCAL_IDS:
		g_value_set_object (value, folks_local_id_details_get_local_ids ((FolksLocalIdDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_POSTAL_ADDRESSES:
		g_value_set_object (value, folks_postal_address_details_get_postal_addresses ((FolksPostalAddressDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_PHONE_NUMBERS:
		g_value_set_object (value, folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_EMAIL_ADDRESSES:
		g_value_set_object (value, folks_email_details_get_email_addresses ((FolksEmailDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_NOTES:
		g_value_set_object (value, folks_note_details_get_notes ((FolksNoteDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_AVATAR:
		g_value_set_object (value, folks_avatar_details_get_avatar ((FolksAvatarDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_STRUCTURED_NAME:
		g_value_set_object (value, folks_name_details_get_structured_name ((FolksNameDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_FULL_NAME:
		g_value_set_string (value, folks_name_details_get_full_name ((FolksNameDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_NICKNAME:
		g_value_set_string (value, folks_name_details_get_nickname ((FolksNameDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_GENDER:
		g_value_set_enum (value, folks_gender_details_get_gender ((FolksGenderDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_URLS:
		g_value_set_object (value, folks_url_details_get_urls ((FolksUrlDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_IM_ADDRESSES:
		g_value_set_object (value, folks_im_details_get_im_addresses ((FolksImDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_GROUPS:
		g_value_set_object (value, folks_group_details_get_groups ((FolksGroupDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_CALENDAR_EVENT_ID:
		g_value_set_string (value, folks_birthday_details_get_calendar_event_id ((FolksBirthdayDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_BIRTHDAY:
		g_value_set_boxed (value, folks_birthday_details_get_birthday ((FolksBirthdayDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_ROLES:
		g_value_set_object (value, folks_role_details_get_roles ((FolksRoleDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_IS_FAVOURITE:
		g_value_set_boolean (value, folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) self));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_ANTI_LINKS:
		g_value_set_object (value, folks_anti_linkable_get_anti_links ((FolksAntiLinkable*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_folks_dummy_full_persona_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	FolksDummyFullPersona * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, FOLKS_DUMMY_TYPE_FULL_PERSONA, FolksDummyFullPersona);
	switch (property_id) {
		case FOLKS_DUMMY_FULL_PERSONA_WEB_SERVICE_ADDRESSES:
		folks_web_service_details_set_web_service_addresses ((FolksWebServiceDetails*) self, g_value_get_object (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_LOCAL_IDS:
		folks_local_id_details_set_local_ids ((FolksLocalIdDetails*) self, g_value_get_object (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_POSTAL_ADDRESSES:
		folks_postal_address_details_set_postal_addresses ((FolksPostalAddressDetails*) self, g_value_get_object (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_PHONE_NUMBERS:
		folks_phone_details_set_phone_numbers ((FolksPhoneDetails*) self, g_value_get_object (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_EMAIL_ADDRESSES:
		folks_email_details_set_email_addresses ((FolksEmailDetails*) self, g_value_get_object (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_NOTES:
		folks_note_details_set_notes ((FolksNoteDetails*) self, g_value_get_object (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_AVATAR:
		folks_avatar_details_set_avatar ((FolksAvatarDetails*) self, g_value_get_object (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_STRUCTURED_NAME:
		folks_name_details_set_structured_name ((FolksNameDetails*) self, g_value_get_object (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_FULL_NAME:
		folks_name_details_set_full_name ((FolksNameDetails*) self, g_value_get_string (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_NICKNAME:
		folks_name_details_set_nickname ((FolksNameDetails*) self, g_value_get_string (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_GENDER:
		folks_gender_details_set_gender ((FolksGenderDetails*) self, g_value_get_enum (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_URLS:
		folks_url_details_set_urls ((FolksUrlDetails*) self, g_value_get_object (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_IM_ADDRESSES:
		folks_im_details_set_im_addresses ((FolksImDetails*) self, g_value_get_object (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_GROUPS:
		folks_group_details_set_groups ((FolksGroupDetails*) self, g_value_get_object (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_CALENDAR_EVENT_ID:
		folks_birthday_details_set_calendar_event_id ((FolksBirthdayDetails*) self, g_value_get_string (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_BIRTHDAY:
		folks_birthday_details_set_birthday ((FolksBirthdayDetails*) self, g_value_get_boxed (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_ROLES:
		folks_role_details_set_roles ((FolksRoleDetails*) self, g_value_get_object (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_IS_FAVOURITE:
		folks_favourite_details_set_is_favourite ((FolksFavouriteDetails*) self, g_value_get_boolean (value));
		break;
		case FOLKS_DUMMY_FULL_PERSONA_ANTI_LINKS:
		folks_anti_linkable_set_anti_links ((FolksAntiLinkable*) self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}



